//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by Btqw.rc
//
#define IDR_MAINFRAME                   2
#define IDD_ABOUTBOX                    100
#define IDD_ARGLIST                     101
#define IDD_BATFILE                     102
#define IDD_CONSTVAL                    103
#define IDD_COPYJOPTS                   104
#define IDD_DEFASS                      105
#define IDD_DEFCONDOPT                  106
#define IDD_DEFTIMOPT                   107
#define IDD_EDITARG                     108
#define IDD_EDITASS                     109
#define IDD_EDITCOND                    110
#define IDD_EDITENV                     111
#define IDD_EDITFMT                     112
#define IDD_EDITREDIR                   113
#define IDD_EDITSEP                     114
#define IDD_ENVLIST                     115
#define IDD_FORMATDEF                   116
#define IDD_JASS                        117
#define IDD_JCOND                       118
#define IDD_JOBFILE                     119
#define IDD_JOBMODE                     120
#define IDD_LOGINHOST                   121
#define IDD_MAILWRITE                   122
#define IDD_NETSTATS                    123
#define IDD_OTHERSIG                    124
#define IDD_PROCPAR                     125
#define IDD_PROGOPTS                    126
#define IDD_REDIRLIST                   127
#define IDD_SEARCHDATA                  128
#define IDD_SEARCHJ                     129
#define IDD_TIMELIMS                    130
#define IDD_TIMER                       131
#define IDD_TITLEPRIO                   132
#define IDD_USERPERM                    133
#define IDD_VARASS                      134
#define IDD_VARCOMM                     135
#define IDD_VARMODE                     136
#define IDD_VSEARCH                     137
#define IDD_WINOPTS                     138
#define IDR_JOBFLOAT                    139
#define IDR_VARFLOAT                    141
#define IDR_JOBS                        145
#define IDR_VARS                        146
#define IDR_VIEWJOB                     148
#define IDC_ARGLIST                     150
#define IDC_NEWARG                      151
#define IDC_EDITARG                     152
#define IDC_DELARG                      153
#define IDC_CONSTVALUE                  154
#define IDC_SCR_CONSTVALUE              155
#define IDC_ASCANC                      156
#define IDC_ASREADY                     157
#define IDC_ARGVAL                      158
#define IDC_ASSVAR                      159
#define IDC_VALUE                       160
#define IDC_SCR_VALUE                   161
#define IDC_ASET                        162
#define IDC_AADD                        163
#define IDC_ASUB                        164
#define IDC_AMULT                       165
#define IDC_ADIV                        166
#define IDC_AMOD                        167
#define IDC_AEXIT                       168
#define IDC_ASIGNAL                     169
#define IDC_ASTART                      170
#define IDC_AREVERSE                    171
#define IDC_ANORMAL                     172
#define IDC_AERROR                      173
#define IDC_AABORT                      174
#define IDC_ACANCEL                     175
#define IDC_CEQ                         176
#define IDC_CNE                         177
#define IDC_CLT                         178
#define IDC_CLE                         179
#define IDC_CGT                         180
#define IDC_CGE                         181
#define IDC_ANOTCRIT                    182
#define IDC_ACRIT                       183
#define IDC_CONDVAR                     184
#define IDC_CNOTCRIT                    185
#define IDC_CCRIT                       186
#define IDC_ENAME                       187
#define IDC_EVALUE                      188
#define IDC_FMTCODE                     189
#define IDC_WIDTH                       190
#define IDC_SCR_WIDTH                   191
#define IDC_TABLEFT                     192
#define IDC_SKIPRIGHT                   193
#define IDC_FD                          194
#define IDC_SCR_FD                      195
#define IDC_STDFILE                     196
#define IDC_CFILE                       197
#define IDC_PIPETO                      198
#define IDC_PIPEFROM                    199
#define IDC_CLOSEFILE                   200
#define IDC_DUPFROM                     201
#define IDC_FD2                         202
#define IDC_SCR_FD2                     203
#define IDC_STDFILE2                    204
#define IDC_FILENAME                    205
#define IDC_BRAC                        206
#define IDC_KET                         207
#define IDC_FREAD                       208
#define IDC_FWRITE                      209
#define IDC_FAPPEND                     210
#define IDC_SEPVALUE                    211
#define IDC_ENVLIST                     212
#define IDC_NEWENV                      213
#define IDC_EDITENV                     214
#define IDC_DELENV                      215
#define IDC_WHAT4                       216
#define IDC_FMTLIST                     217
#define IDC_NEWFMT                      218
#define IDC_NEWSEP                      219
#define IDC_EDITFMT                     220
#define IDC_DELFMT                      221
#define IDC_RESETDEFLT                  222
#define IDC_ASSLIST                     223
#define IDC_NEWASS                      224
#define IDC_EDITASS                     225
#define IDC_ASSDEL                      226
#define IDC_CONDLIST                    227
#define IDC_NEWCOND                     228
#define IDC_EDITCOND                    229
#define IDC_CONDDEL                     230
#define IDC_JUREAD                      231
#define IDC_JUWRITE                     232
#define IDC_JUREVEAL                    233
#define IDC_JUDISPMODE                  234
#define IDC_JUSETMODE                   235
#define IDC_JUASSOWN                    236
#define IDC_JUASSGOWN                   237
#define IDC_JUGOWN                      238
#define IDC_JUGGROUP                    239
#define IDC_JUDELETE                    240
#define IDC_JUKILL                      241
#define IDC_JGREAD                      242
#define IDC_JGWRITE                     243
#define IDC_JGREVEAL                    244
#define IDC_JGDISPMODE                  245
#define IDC_JGSETMODE                   246
#define IDC_JGASSGOWN                   247
#define IDC_JGASSOWN                    248
#define IDC_JGGOWN                      249
#define IDC_JGGGROUP                    250
#define IDC_JGDELETE                    251
#define IDC_JGKILL                      252
#define IDC_JOREAD                      253
#define IDC_JOWRITE                     254
#define IDC_JOREVEAL                    255
#define IDC_JODISPMODE                  256
#define IDC_JOSETMODE                   257
#define IDC_JOASSGOWN                   258
#define IDC_JOASSOWN                    259
#define IDC_JOGOWN                      260
#define IDC_JOGGROUP                    261
#define IDC_JODELETE                    262
#define IDC_JOKILL                      263
#define IDC_USER                        264
#define IDC_GROUP                       265
#define IDC_UNIXHOST                    266
#define IDC_CLIENTHOST                  267
#define IDC_USERNAME                    268
#define IDC_PASSWD                      269
#define IDC_MAIL                        270
#define IDC_WRITE                       271
#define IDC_HOST                        272
#define IDC_NS_PROBESENT                273
#define IDC_CONNECTED                   274
#define IDC_NS_SYNCREQ                  275
#define IDC_NS_SYNCDONE                 276
#define IDC_SIG_HANGUP                  277
#define IDC_SIG_INTERRUPT               278
#define IDC_SIG_QUIT                    279
#define IDC_SIG_TERMINATE               280
#define IDC_SIG_KILL                    281
#define IDC_DIRECTORY                   282
#define IDC_UR                          283
#define IDC_UW                          284
#define IDC_UX                          285
#define IDC_GR                          286
#define IDC_GW                          287
#define IDC_GX                          288
#define IDC_OR                          289
#define IDC_OW                          290
#define IDC_OX                          291
#define IDC_ULIMIT                      292
#define IDC_SCR_ULIMIT                  293
#define IDC_NEXITL                      294
#define IDC_SCR_NEXITL                  295
#define IDC_NEXITU                      296
#define IDC_SCR_NEXITU                  297
#define IDC_EEXITL                      298
#define IDC_SCR_EEXITL                  299
#define IDC_EEXITU                      300
#define IDC_SCR_EEXITU                  301
#define IDC_ADVTERR                     302
#define IDC_NADVTERR                    303
#define IDC_REMRUNNABLE                 304
#define IDC_JOBQNAME                    305
#define IDC_JOBQUEUE                    306
#define IDC_INCNULL                     307
#define IDC_DELJOBSNAME                 308
#define IDC_NEVER                       309
#define IDC_ALWAYS                      310
#define IDC_PROBE_IGNORE                311
#define IDC_PROBE_WARN                  312
#define IDC_LOCALONLY                   313
#define IDC_DISPALL                     314
#define IDC_POLLTIME                    315
#define IDC_SCR_POLLTIME                316
#define IDC_BINUNQ                      317
#define IDC_SJXBC                       318
#define IDC_SJBAT                       319
#define IDC_REDIRLIST                   320
#define IDC_NEWREDIR                    321
#define IDC_EDITREDIR                   322
#define IDC_DELREDIR                    323
#define IDC_LOOKFOR                     324
#define IDC_SEARCH_FORWARD              325
#define IDC_SEARCH_BACK                 326
#define IDC_WRAPROUND                   327
#define IDC_IGNORECASE                  328
#define IDC_SRCH_USER                   329
#define IDC_SRCH_JTITLE                 330
#define IDC_TIMEISSET                   331
#define IDC_MIN                         332
#define IDC_HOUR                        333
#define IDC_WDAY                        334
#define IDC_MDAY                        335
#define IDC_MON                         336
#define IDC_YEAR                        337
#define IDC_SCR_MIN                     338
#define IDC_SCR_HOUR                    339
#define IDC_SCR_WDAY                    340
#define IDC_SCR_MDAY                    341
#define IDC_SCR_MON                     342
#define IDC_SCR_YEAR                    343
#define IDC_COLON                       344
#define IDC_DELETE                      345
#define IDC_RETAIN                      346
#define IDC_REPMINS                     347
#define IDC_REPHOURS                    348
#define IDC_REPDAYS                     349
#define IDC_REPWEEKS                    350
#define IDC_REPMONTHSB                  351
#define IDC_REPMONTHSE                  352
#define IDC_REPYEARS                    353
#define IDC_MESS_REPEATEVERY            354
#define IDC_REPEAT                      355
#define IDC_SCR_REPEAT                  356
#define IDC_MONDAYNAME                  357
#define IDC_MONTHDAY                    358
#define IDC_SCR_MONTHDAY                359
#define IDC_MESS_AVOIDING               360
#define IDC_AVSUN                       361
#define IDC_AVMON                       362
#define IDC_AVTUE                       363
#define IDC_AVWED                       364
#define IDC_AVTHU                       365
#define IDC_AVFRI                       366
#define IDC_AVSAT                       367
#define IDC_AVHOLIDAY                   368
#define IDC_MESS_NOTPOSS                369
#define IDC_NPSKIP                      370
#define IDC_NPDELCURR                   371
#define IDC_NPDELALL                    372
#define IDC_NPCATCHUP                   373
#define IDC_MESS_COMESTO                374
#define IDC_REPRESULT                   375
#define IDC_DELTIME                     376
#define IDC_SCR_DELTIME                 377
#define IDC_COLON2                      378
#define IDC_COLON3                      379
#define IDC_SEC                         380
#define IDC_SCR_SEC                     381
#define IDC_RTOFF                       382
#define IDC_KW_TERM                     383
#define IDC_KW_KILL                     384
#define IDC_KW_HUP                      385
#define IDC_KW_INT                      386
#define IDC_KW_QUIT                     387
#define IDC_KW_ARLM                     388
#define IDC_KW_BUS                      389
#define IDC_KW_SEGV                     390
#define IDC_MIN2                        391
#define IDC_SCR_MIN2                    392
#define IDC_SEC2                        393
#define IDC_SCR_SEC2                    394
#define IDC_TITLE                       395
#define IDC_CMDINTERP                   396
#define IDC_PRIORITY                    397
#define IDC_SCR_PRIORITY                398
#define IDC_LOADLEV                     399
#define IDC_SCR_LOADLEV                 400
#define IDC_RADMIN                      401
#define IDC_WADMIN                      402
#define IDC_CREATE                      403
#define IDC_SPCREATE                    404
#define IDC_SSTOP                       405
#define IDC_UMASK                       406
#define IDC_ORUG                        407
#define IDC_ORUO                        408
#define IDC_ORGO                        409
#define IDC_MAXLL                       410
#define IDC_TOTLL                       411
#define IDC_SPECLL                      412
#define IDC_DVARNAME                    413
#define IDC_DVARCOMMENT                 414
#define IDC_AVARVALUE                   415
#define IDC_SCR_AVARVALUE               416
#define IDC_AVARCOMMENT                 417
#define IDC_VUREAD                      418
#define IDC_VUWRITE                     419
#define IDC_VUREVEAL                    420
#define IDC_VUDISPMODE                  421
#define IDC_VUSETMODE                   422
#define IDC_VUASSOWN                    423
#define IDC_VUASSGOWN                   424
#define IDC_VUGOWN                      425
#define IDC_VUGGROUP                    426
#define IDC_VUDELETE                    427
#define IDC_VGREAD                      428
#define IDC_VGWRITE                     429
#define IDC_VGREVEAL                    430
#define IDC_VGDISPMODE                  431
#define IDC_VGSETMODE                   432
#define IDC_VGASSOWN                    433
#define IDC_VGASSGOWN                   434
#define IDC_VGGOWN                      435
#define IDC_VGGGROUP                    436
#define IDC_VGDELETE                    437
#define IDC_VOREAD                      438
#define IDC_VOWRITE                     439
#define IDC_VOREVEAL                    440
#define IDC_VODISPMODE                  441
#define IDC_VOSETMODE                   442
#define IDC_VOASSOWN                    443
#define IDC_VOASSGOWN                   444
#define IDC_VOGOWN                      445
#define IDC_VOGGROUP                    446
#define IDC_VODELETE                    447
#define IDC_SRCH_VNAME                  448
#define IDC_VVALUE                      449
#define IDC_VCOMMENT                    450
#define IDS_JANUARY                     500
#define IDS_FEBRUARY                    501
#define IDS_MARCH                       502
#define IDS_APRIL                       503
#define IDS_MAY                         504
#define IDS_JUNE                        505
#define IDS_JULY                        506
#define IDS_AUGUST                      507
#define IDS_SEPTEMBER                   508
#define IDS_OCTOBER                     509
#define IDS_NOVEMBER                    510
#define IDS_DECEMBER                    511
#define IDS_SUNDAY                      512
#define IDS_MONDAY                      513
#define IDS_TUESDAY                     514
#define IDS_WEDNESDAY                   515
#define IDS_THURSDAY                    516
#define IDS_FRIDAY                      517
#define IDS_SATURDAY                    518
#define IDS_SUN                         519
#define IDS_MON                         520
#define IDS_TUE                         521
#define IDS_WED                         522
#define IDS_THUR                        523
#define IDS_FRI                         524
#define IDS_SAT                         525
#define IDS_Hday                        526
#define IDS_DELETE                      527
#define IDS_RETAIN                      528
#define IDS_MINUTES                     529
#define IDS_HOURS                       530
#define IDS_DAYS                        531
#define IDS_WEEKS                       532
#define IDS_MONTHSB                     533
#define IDS_MONTHSE                     534
#define IDS_YEARS                       535
#define IDS_LOTSCONDS                   536
#define IDS_LOTSASSES                   537
#define IDS_REMRUNNABLE                 538
#define IDS_EXPORT                      539
#define IDS_CLUSTER                     540
#define IDS_PROG_NONE                   541
#define IDS_PROG_DONE                   542
#define IDS_PROG_ERROR                  543
#define IDS_PROG_ABORTED                544
#define IDS_PROG_CANCELLED              545
#define IDS_PROG_STARTUP1               546
#define IDS_PROG_STARTUP2               547
#define IDS_PROG_RUNNING                548
#define IDS_PROG_FINISHED               549
#define IDS_CONDOP                      550
#define IDS_CEQ                         551
#define IDS_CNE                         552
#define IDS_CLT                         553
#define IDS_CLE                         554
#define IDS_CGT                         555
#define IDS_CGE                         556
#define IDS_ASSOP                       557
#define IDS_AASSIGN                     558
#define IDS_AINCR                       559
#define IDS_ADECR                       560
#define IDS_AMULT                       561
#define IDS_ADIV                        562
#define IDS_AMOD                        563
#define IDS_AEXIT                       564
#define IDS_ASIGNAL                     565
#define IDS_STDIN_NAME                  566
#define IDS_STDOUT_NAME                 567
#define IDS_STDERR_NAME                 568
#define IDS_UNKNOWNCI                   569
#define IDS_DEF_JFMT                    570
#define IDS_DEF_V1FMT                   571
#define IDS_EDITINGJFMT                 572
#define IDS_EDITINGV1FMT                573
#define IDS_JFORMAT_A                   600
#define IDS_JFORMAT_C                   602
#define IDS_JFORMAT_D                   603
#define IDS_JFORMAT_E                   604
#define IDS_JFORMAT_G                   606
#define IDS_JFORMAT_H                   607
#define IDS_JFORMAT_I                   608
#define IDS_JFORMAT_L                   611
#define IDS_JFORMAT_M                   612
#define IDS_JFORMAT_N                   613
#define IDS_JFORMAT_O                   614
#define IDS_JFORMAT_P                   615
#define IDS_JFORMAT_R                   617
#define IDS_JFORMAT_S                   618
#define IDS_JFORMAT_T                   619
#define IDS_JFORMAT_U                   620
#define IDS_JFORMAT_W                   622
#define IDS_JFORMAT_X                   623
#define IDS_JFORMAT_aa                  630
#define IDS_JFORMAT_bb                  631
#define IDS_JFORMAT_cc                  632
#define IDS_JFORMAT_dd                  633
#define IDS_JFORMAT_ee                  634
#define IDS_JFORMAT_ff                  635
#define IDS_JFORMAT_gg                  636
#define IDS_JFORMAT_hh                  637
#define IDS_JFORMAT_ii                  638
#define IDS_JFORMAT_kk                  640
#define IDS_JFORMAT_ll                  641
#define IDS_JFORMAT_mm                  642
#define IDS_JFORMAT_nn                  643
#define IDS_JFORMAT_oo                  644
#define IDS_JFORMAT_pp                  645
#define IDS_JFORMAT_qq                  646
#define IDS_JFORMAT_rr                  647
#define IDS_JFORMAT_ss                  648
#define IDS_JFORMAT_tt                  649
#define IDS_JFORMAT_uu                  650
#define IDS_JFORMAT_xx                  653
#define IDS_JFORMAT_yy                  654
#define IDS_VFORMAT_C                   702
#define IDS_VFORMAT_E                   704
#define IDS_VFORMAT_G                   706
#define IDS_VFORMAT_K                   710
#define IDS_VFORMAT_M                   712
#define IDS_VFORMAT_N                   713
#define IDS_VFORMAT_U                   720
#define IDS_VFORMAT_V                   721
#define IDS_SJFORMAT_A                  800
#define IDS_SJFORMAT_C                  802
#define IDS_SJFORMAT_D                  803
#define IDS_SJFORMAT_E                  804
#define IDS_SJFORMAT_G                  806
#define IDS_SJFORMAT_H                  807
#define IDS_SJFORMAT_I                  808
#define IDS_SJFORMAT_L                  811
#define IDS_SJFORMAT_M                  812
#define IDS_SJFORMAT_N                  813
#define IDS_SJFORMAT_O                  814
#define IDS_SJFORMAT_P                  815
#define IDS_SJFORMAT_R                  817
#define IDS_SJFORMAT_S                  818
#define IDS_SJFORMAT_T                  819
#define IDS_SJFORMAT_U                  820
#define IDS_SJFORMAT_W                  822
#define IDS_SJFORMAT_X                  823
#define IDS_SJFORMAT_aa                 830
#define IDS_SJFORMAT_bb                 831
#define IDS_SJFORMAT_cc                 832
#define IDS_SJFORMAT_dd                 833
#define IDS_SJFORMAT_ee                 834
#define IDS_SJFORMAT_ff                 835
#define IDS_SJFORMAT_gg                 836
#define IDS_SJFORMAT_hh                 837
#define IDS_SJFORMAT_ii                 838
#define IDS_SJFORMAT_kk                 840
#define IDS_SJFORMAT_ll                 841
#define IDS_SJFORMAT_mm                 842
#define IDS_SJFORMAT_nn                 843
#define IDS_SJFORMAT_oo                 844
#define IDS_SJFORMAT_pp                 845
#define IDS_SJFORMAT_qq                 846
#define IDS_SJFORMAT_rr                 847
#define IDS_SJFORMAT_ss                 848
#define IDS_SJFORMAT_tt                 849
#define IDS_SJFORMAT_uu                 850
#define IDS_SJFORMAT_xx                 853
#define IDS_SJFORMAT_yy                 854
#define IDS_SVFORMAT_C                  902
#define IDS_SVFORMAT_E                  904
#define IDS_SVFORMAT_G                  906
#define IDS_SVFORMAT_K                  911
#define IDS_SVFORMAT_M                  912
#define IDS_SVFORMAT_N                  913
#define IDS_SVFORMAT_U                  920
#define IDS_SVFORMAT_V                  921
#define IDP_TOO_MANY_ROWS               2000
#define IDP_NOJOBSELECTED               2001
#define IDP_NOVARSELECTED               2002
#define IDP_NOSEARCHSTR                 2003
#define IDP_NOTFOUND                    2004
#define IDP_XBENQ_PASSREQ               2005
#define IDP_XBENQ_BADPASSWD             2006
#define IDP_XBENQ_UNKNOWN               2007
#define IDP_XBENQ_BADCLIENT             2008
#define IDP_XBENQ_UNKNOWNU              2009
#define IDP_XBENQ_UNKNOWNG              2010
#define IDP_CONNDIED                    2011
#define IDP_PREVINSTANCE                2012
#define IDP_NO_SERVER                   2013
#define IDP_NO_HOSTFILE                 2014
#define IDP_HF_INVALIDHOST              2015
#define IDP_HF_BADTIMEOUT               2016
#define IDP_HF_NOALIAS                  2017
#define IDP_SK_CCLISTSOCK               2018
#define IDP_SK_CCPROBESOCK              2019
#define IDP_GBTU_NOBIND                 2020
#define IDP_GBTU_NOSEND                 2021
#define IDP_GBTU_NORECV                 2022
#define IDP_GBTU_NVALID                 2023
#define IDP_PROBE_SOCKERR               2024
#define IDP_PROBE_BINDERR               2025
#define IDP_PROBE_SENDERR               2026
#define IDP_GBTU_NOSOCK                 2027
#define IDP_NOCILIST                    2028
#define IDP_ASYNCSEL                    2029
#define IDP_LISTASYNCSEL                2030
#define IDP_PROBEASYNCSEL               2031
#define IDP_CCFEEDSOCKET                2032
#define IDP_CCOFEEDSOCKET               2033
#define IDP_CSFEEDSOCKET                2034
#define IDP_CCTEMPFILE                  2035
#define IDP_CWTEMPFILE                  2036
#define IDP_NOMEMFORJOB                 2037
#define IDP_INVALIDDOC                  2038
#define IDP_JOBTOOWIDE                  2039
#define IDP_JOBTOOLONG                  2040
#define IDP_CONFDELJ                    2041
#define IDP_JDNOSEARCHS                 2042
#define IDP_JDSNOTFOUND                 2043
#define IDP_JPNOSEARCHS                 2044
#define IDP_JPNOITEM                    2045
#define IDP_SYSM_NOPERM                 2046
#define IDP_JOBM_OK                     2047
#define IDP_JOBM_NEXIST                 2048
#define IDP_JOBM_VNEXIST                2049
#define IDP_JOBM_NOPERM                 2050
#define IDP_JOBM_VNOPERM                2051
#define IDP_JOBM_NOPRIV                 2052
#define IDP_JOBM_SYSVAR                 2053
#define IDP_JOBM_SYSVTYPE               2054
#define IDP_JOBM_FULLUP                 2055
#define IDP_JOBM_ISRUNNING              2056
#define IDP_JOBM_REMVINLOCJ             2057
#define IDP_JOBM_LOCVINREMJ             2058
#define IDP_JOBM_MINPRIV                2059
#define IDP_VARM_OK                     2060
#define IDP_VARM_EXISTS                 2061
#define IDP_VARM_NEXISTS                2062
#define IDP_VARM_CLASHES                2063
#define IDP_VARM_NOPERM                 2064
#define IDP_VARM_NOPRIV                 2065
#define IDP_VARM_SYNC                   2066
#define IDP_VARM_SYSVAR                 2067
#define IDP_VARM_SYSVTYPE               2068
#define IDP_VARM_FULLUP                 2069
#define IDP_VARM_DSYSVAR                2070
#define IDP_VARM_INUSE                  2071
#define IDP_VARM_MINPRIV                2072
#define IDP_VARM_DELREMOTE              2073
#define IDP_VARM_UNKREMUSER             2074
#define IDP_VARM_UNKREMGRP              2075
#define IDP_VARM_RENEXISTS              2076
#define IDP_NETM_OK                     2077
#define IDP_NETM_LOCKNONE               2078
#define IDP_NETM_LOCKOK                 2079
#define IDP_NETM_LOCKPRIO               2080
#define IDP_NETM_NOFORK                 2081
#define IDP_NETM_NBADMSGQ               2082
#define IDP_NETM_NTIMEOUT               2083
#define IDP_NETM_HOSTOFFLINE            2084
#define IDP_NETM_HOSTDIED               2085
#define IDP_NETM_CONNFAIL               2086
#define IDP_NOTPERM                     2087
#define IDP_JRUNNING                    2088
#define IDP_NOTIMETOADV                 2089
#define IDP_NOTALLDAYS                  2090
#define IDP_TOOMANYCONDS                2091
#define IDP_NOCVARSEL                   2092
#define IDP_NOCVALUE                    2093
#define IDP_TOOMANYASSES                2094
#define IDP_NOAFLAGSSET                 2095
#define IDP_NOAVARSEL                   2096
#define IDP_NOAVALUE                    2097
#define IDP_NORMBADRANGE                2098
#define IDP_ERRBADRANGE                 2099
#define IDP_NOFILENAME                  2100
#define IDP_JLTMINMODE                  2101
#define IDP_VLTMINMODE                  2102
#define IDP_VNOTPERM                    2103
#define IDP_NOTARITHVAR                 2104
#define IDP_VNOTFOUND                   2105
#define IDP_CONSTDIVZERO                2106
#define IDP_NOVVALUE                    2107
#define IDP_CCJOBQFILE                  2108
#define IDP_CWJOBQFILE                  2109
#define IDP_CWBATFILE                   2110
#define IDP_CDJOBQFILE                  2111
#define IDP_CRMSGFILE                   2112
#define IDP_ARGDEFERRS                  2113
#define IDP_NOCODESEL                   2114
#define IDP_TOOMANYFMTS                 2115
#define IDP_SAVEPROPTS                  2116
#define ID_JOBS_VIEWJOB                 32799
#define ID_WINDOW_NEWJOBWINDOW          32805
#define ID_SEARCH_SEARCHFOR             32811
#define ID_SEARCH_SEARCHFORWARD         32812
#define ID_SEARCH_SEARCHBACKWARDS       32813
#define ID_FILE_PROGRAMOPTIONS          32817
#define ID_WINDOW_WINDOWOPTIONS         32818
#define ID_WINDOW_NEWVARWINDOW          32819
#define ID_ACTION_DELETEJOB             32821
#define ID_ACTION_PERMISSIONS           32822
#define ID_ACTION_TITLEPRILOADLEV       32823
#define ID_ACTION_SETRUNNABLE           32824
#define ID_ACTION_SETCANCELLED          32825
#define ID_ACTION_FORCERUN              32826
#define ID_ACTION_KILLJOB               32827
#define ID_JOBS_TIME                    32828
#define ID_JOBS_PROCPARAM               32829
#define ID_JOBS_MAIL                    32830
#define ID_JOBS_ARGUMENTS               32831
#define ID_JOBS_ENVIRONMENT             32832
#define ID_JOBS_REDIRECTIONS            32833
#define ID_CONDITIONS_JOBCONDITIONS     32834
#define ID_CONDITIONS_JOBASSIGNMENTS    32835
#define ID_VARS_INCREMENT               32837
#define ID_VARIABLES_ASSIGN             32838
#define ID_VARIABLES_INCREMENT          32839
#define ID_VARIABLES_DECREMENT          32840
#define ID_VARIABLES_MULTIPLY           32841
#define ID_VARIABLES_DIVIDE             32842
#define ID_VARIABLES_REMAINDER          32843
#define ID_VARIABLES_SETCONSTANT        32844
#define ID_VARIABLES_SETCOMMENT         32845
#define ID_ACTION_QUITJOB               32846
#define ID_ACTION_OTHERSIGNAL           32847
#define ID_FILE_SAVEFILE                32848
#define ID_ACTION_GOJOB                 32849
#define ID_JOBS_ADVANCETIME             32850
#define ID_FILE_TIMEDEFAULTS            32851
#define ID_FILE_CONDITIONDEFAULTS       32852
#define ID_FILE_ASSIGNMENTDEFAULTS      32853
#define ID_JOBS_UNQUEUEJOB              32854
#define ID_JOBS_COPYJOB                 32855
#define ID_JOBS_COPYOPTIONSINJOB        32856
#define ID_WINDOW_JOBDISPLAYFORMAT      32858
#define ID_WINDOW_VARDISPLAYFMTLINE1    32859
#define ID_WINDOW_JOBLISTFONT           32861
#define ID_WINDOW_JOBDATALISTFONT       32863
#define ID_JOBS_INVOKEBTRW              32864
#define ID_JOBS_TIMELIMITS              32865
#define ID_FILE_NETWORKSTATS            32866
#define ID_FILE_USERPERMS               32867
#define ID_WINDOW_SAVEWIDTHSASDEFAULT   32868
#define ID_FILE_JOBCOLOURS              32890
#define ID_JCOLOUR_READY                32891
#define ID_JCOLOUR_STARTUP              32893
#define ID_JCOLOUR_RUNNING              32894
#define ID_JCOLOUR_FINISHED             32895
#define ID_JCOLOUR_CANCELLED            32896
#define ID_JCOLOUR_ERROR                32897
#define ID_JCOLOUR_ABORT                32898
#define ID_WJCOLOUR_READY               32899
#define ID_WJCOLOUR_CANCELLED           32900
#define ID_WJCOLOUR_RUNNING             32901
#define ID_WJCOLOUR_STARTUP             32902
#define ID_WJCOLOUR_FINISHED            32903
#define ID_WJCOLOUR_ERROR               32904
#define ID_WJCOLOUR_ABORT               32905
#define ID_FILE_JCOLOUR_COPYTOPROG      32906
#define ID_FILE_JCOLOUR_COPYTOWIN       32907

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        148
#define _APS_NEXT_COMMAND_VALUE         32908
#define _APS_NEXT_CONTROL_VALUE         451
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif
