// "About BTRSETW" Dialog Box (IDD_ABOUTBOX == 100)


/*
const DWORD a100HelpIDs[]=
{
	0, 0
};
*/

// "Assignment defaults" Dialog Box (IDD_DEFASS == 101)

#define IDH_101_162	10616933	// Assignment defaults: "Normal exit" (Button)
#define IDH_101_163	10682469	// Assignment defaults: "Error exit" (Button)
#define IDH_101_164	10748005	// Assignment defaults: "Abort" (Button)
#define IDH_101_165	10813541	// Assignment defaults: "Cancel" (Button)
#define IDH_101_166	10879077	// Assignment defaults: "Ignore" (Button)
#define IDH_101_167	10944613	// Assignment defaults: "Hold job" (Button)
#define IDH_101_150	9830501	// Assignment defaults: "" (Edit)
#define IDH_101_152	9961573	// Assignment defaults: "Set" (Button)
#define IDH_101_153	10027109	// Assignment defaults: "+" (Button)
#define IDH_101_154	10092645	// Assignment defaults: "-" (Button)
#define IDH_101_155	10158181	// Assignment defaults: "X" (Button)
#define IDH_101_156	10223717	// Assignment defaults: "/" (Button)
#define IDH_101_157	10289253	// Assignment defaults: "Md" (Button)
#define IDH_101_158	10354789	// Assignment defaults: "Exit" (Button)
#define IDH_101_159	10420325	// Assignment defaults: "Sig" (Button)
#define IDH_101_160	10485861	// Assignment defaults: "On start" (Button)
#define IDH_101_161	10551397	// Assignment defaults: "REVERSE on exit" (Button)

/*
*/

// "Condition defaults" Dialog Box (IDD_DEFCOND == 102)

#define IDH_102_168	11010150	// Condition defaults: "=" (Button)
#define IDH_102_150	9830502	// Condition defaults: "" (Edit)
#define IDH_102_174	11403366	// Condition defaults: "Ignore" (Button)
#define IDH_102_175	11468902	// Condition defaults: "Hold job" (Button)

/*
*/

// "Time defaults" Dialog Box (IDD_DEFTIMES == 103)

#define IDH_103_186	12189799	// Time defaults: "0" (Edit)
#define IDH_103_189	12386407	// Time defaults: "0" (Edit)
#define IDH_103_192	12583015	// Time defaults: "Sun" (Button)
#define IDH_103_176	11534439	// Time defaults: "Run and delete" (Button)
#define IDH_103_177	11599975	// Time defaults: "Run and retain" (Button)
#define IDH_103_201	13172839	// Time defaults: "Skip" (Button)
#define IDH_103_178	11665511	// Time defaults: "Minutes" (Button)
#define IDH_103_202	13238375	// Time defaults: "Delay Current" (Button)
#define IDH_103_203	13303911	// Time defaults: "Delay all" (Button)
#define IDH_103_204	13369447	// Time defaults: "Catch up" (Button)

/*
*/

// "New Host Name" Dialog Box (IDD_HOST == 104)

#define IDH_104_209	13697128	// New Host Name: "Probe first" (Button)
#define IDH_104_205	13434984	// New Host Name: "" (Edit)
#define IDH_104_206	13500520	// New Host Name: "" (Edit)
#define IDH_104_207	13566056	// New Host Name: "0" (Edit)

/*
*/

// "Job permissions" Dialog Box (IDD_JOBMODE == 105)

#define IDH_105_210	13762665	// Job permissions: "Read" (Button)
#define IDH_105_235	15401065	// Job permissions: "" (Button)
#define IDH_105_243	15925353	// Job permissions: "" (ComboBox)
#define IDH_105_244	15990889	// Job permissions: "" (ComboBox)
#define IDH_105_221	14483561	// Job permissions: "" (Button)

/*
*/

// "Please log in to Unix Host...." Dialog Box (IDD_LOGINHOST == 106)

#define IDH_106_245	16056426	// Please log in to Unix Host....: "" (Edit)
#define IDH_106_246	16121962	// Please log in to Unix Host....: "" (Edit)
#define IDH_106_247	16187498	// Please log in to Unix Host....: "" (Edit)
#define IDH_106_248	16253034	// Please log in to Unix Host....: "" (Edit)

/*
*/

// "Login as new user or log out" Dialog Box (IDD_LOGINOUT == 107)

#define IDH_107_249	16318571	// Login as new user or log out: "" (Edit)
#define IDH_107_250	16384107	// Login as new user or log out: "" (Edit)
#define IDH_107_251	16449643	// Login as new user or log out: "Login as new user" (Button)
#define IDH_107_252	16515179	// Login as new user or log out: "Log out" (Button)

/*
*/

// "Select New Group" Dialog Box (IDD_NEWGROUP == 108)

#define IDH_108_244	15990892	// Select New Group: "" (ComboBox)

/*
*/

// "Port Numbers" Dialog Box (IDD_PORTNUMS == 109)

#define IDH_109_254	16646253	// Port Numbers: "0" (Edit)
#define IDH_109_256	16777325	// Port Numbers: "Incr" (Button)
#define IDH_109_257	16842861	// Port Numbers: "Decr" (Button)
#define IDH_109_258	16908397	// Port Numbers: "0" (Edit)
#define IDH_109_260	17039469	// Port Numbers: "0" (Edit)
#define IDH_109_262	17170541	// Port Numbers: "0" (Edit)
#define IDH_109_264	17301613	// Port Numbers: "0" (Edit)
#define IDH_109_266	17432685	// Port Numbers: "0" (Edit)
#define IDH_109_268	17563757	// Port Numbers: "0" (Edit)
#define IDH_109_270	17694829	// Port Numbers: "Save Settings to INI file" (Button)
#define IDH_109_253	16580717	// Port Numbers: "Set Default" (Button)

/*
*/

// "Process parameters" Dialog Box (IDD_PROCPAR == 110)

#define IDH_110_281	18415726	// Process parameters: "" (Edit)
#define IDH_110_283	18546798	// Process parameters: "0" (Edit)
#define IDH_110_287	18808942	// Process parameters: "0" (Edit)
#define IDH_110_291	19071086	// Process parameters: "Advance time" (Button)
#define IDH_110_292	19136622	// Process parameters: "Do not advance time" (Button)
#define IDH_110_293	19202158	// Process parameters: "Local to server" (Button)
#define IDH_110_294	19267694	// Process parameters: "Export" (Button)
#define IDH_110_271	17760366	// Process parameters: "" (Edit)
#define IDH_110_295	19333230	// Process parameters: "Remote runnable" (Button)
#define IDH_110_272	17825902	// Process parameters: "R" (Button)

/*
*/

// "Program Options" Dialog Box (IDD_PROGOPTS == 111)

#define IDH_111_328	21495919	// Program Options: "" (Edit)
#define IDH_111_296	19398767	// Program Options: "Verbose" (Button)
#define IDH_111_297	19464303	// Program Options: "Binary mode (no CR conversion)" (Button)

/*
*/

// "Queue defaults" Dialog Box (IDD_QUEUEDEFS == 112)

#define IDH_112_300	19660912	// Queue defaults: "0" (Edit)
#define IDH_112_302	19791984	// Queue defaults: "0" (Edit)
#define IDH_112_298	19529840	// Queue defaults: "" (Edit)
#define IDH_112_299	19595376	// Queue defaults: "" (ComboBox)

/*
*/

// "Job time limits" Dialog Box (IDD_TIMELIMS == 113)

#define IDH_113_323	21168241	// Job time limits: "" (Edit)
#define IDH_113_304	19923057	// Job time limits: "0" (Edit)
#define IDH_113_306	20054129	// Job time limits: "" (Edit)
#define IDH_113_314	20578417	// Job time limits: "OFF" (Button)
#define IDH_113_315	20643953	// Job time limits: "Sigterm" (Button)

/*
*/

// "New" Dialog Box


/*
const DWORD a30721HelpIDs[]=
{
	0, 0
};
*/

extern	BOOL	do_contexthelp(const UINT, const DWORD *);
