; btqw.def : Declares the module parameters for the application.

NAME         BTQW
DESCRIPTION  'BTQW Batch queue for Windows'

; CODE         PRELOAD MOVEABLE DISCARDABLE
; DATA         PRELOAD MOVEABLE MULTIPLE

HEAPSIZE     1024   ; initial heap size
; Stack size is passed as argument to linker's /STACK option


