// "About BTQW" Dialog Box (IDD_ABOUTBOX == 100)


/*
const DWORD a100HelpIDs[]=
{
	0, 0
};
*/

// "Job Argument List" Dialog Box (IDD_ARGLIST == 101)

#define IDH_101_150	9830501	// Job Argument List: "" (ListBox)
#define IDH_101_151	9896037	// Job Argument List: "New" (Button)
#define IDH_101_152	9961573	// Job Argument List: "Edit" (Button)
#define IDH_101_153	10027109	// Job Argument List: "Delete" (Button)

/*
*/

// "Constant for Arithmetic ops" Dialog Box (IDD_CONSTVAL == 103)

#define IDH_103_154	10092647	// Constant for Arithmetic ops: "" (Edit)

/*
*/

// "Copy job options" Dialog Box (IDD_COPYJOPTS == 104)

#define IDH_104_156	10223720	// Copy job options: "As cancelled" (Button)
#define IDH_104_157	10289256	// Copy job options: "As ready to run" (Button)

/*
*/

// "Assignment defaults" Dialog Box (IDD_DEFASS == 105)

#define IDH_105_162	10616937	// Assignment defaults: "Set" (Button)
#define IDH_105_170	11141225	// Assignment defaults: "On start" (Button)
#define IDH_105_182	11927657	// Assignment defaults: "Ignore" (Button)
#define IDH_105_160	10485865	// Assignment defaults: "" (Edit)

/*
*/

// "Condition defaults" Dialog Box (IDD_DEFCONDOPT == 106)

#define IDH_106_185	12124266	// Condition defaults: "Ignore" (Button)
#define IDH_106_176	11534442	// Condition defaults: "=" (Button)
#define IDH_106_160	10485866	// Condition defaults: "" (Edit)

/*
*/

// "Time defaults" Dialog Box (IDD_DEFTIMOPT == 107)

#define IDH_107_370	24248427	// Time defaults: "Skip" (Button)
#define IDH_107_355	23265387	// Time defaults: "0" (Edit)
#define IDH_107_358	23461995	// Time defaults: "0" (Edit)
#define IDH_107_361	23658603	// Time defaults: "Sun" (Button)
#define IDH_107_345	22610027	// Time defaults: "Run and delete" (Button)

/*
*/

// "Edit Argument" Dialog Box (IDD_EDITARG == 108)

#define IDH_108_158	10354796	// Edit Argument: "" (Edit)

/*
*/

// "Edit Assignment" Dialog Box (IDD_EDITASS == 109)

#define IDH_109_162	10616941	// Edit Assignment: "Set" (Button)
#define IDH_109_163	10682477	// Edit Assignment: "+" (Button)
#define IDH_109_164	10748013	// Edit Assignment: "-" (Button)
#define IDH_109_165	10813549	// Edit Assignment: "X" (Button)
#define IDH_109_166	10879085	// Edit Assignment: "/" (Button)
#define IDH_109_167	10944621	// Edit Assignment: "Md" (Button)
#define IDH_109_168	11010157	// Edit Assignment: "Exit" (Button)
#define IDH_109_169	11075693	// Edit Assignment: "Sig" (Button)
#define IDH_109_170	11141229	// Edit Assignment: "On start" (Button)
#define IDH_109_171	11206765	// Edit Assignment: "REVERSE on exit" (Button)
#define IDH_109_172	11272301	// Edit Assignment: "Normal exit" (Button)
#define IDH_109_173	11337837	// Edit Assignment: "Error exit" (Button)
#define IDH_109_174	11403373	// Edit Assignment: "Abort" (Button)
#define IDH_109_175	11468909	// Edit Assignment: "Cancel" (Button)
#define IDH_109_182	11927661	// Edit Assignment: "Ignore" (Button)
#define IDH_109_159	10420333	// Edit Assignment: "" (ComboBox)
#define IDH_109_183	11993197	// Edit Assignment: "Hold job" (Button)
#define IDH_109_160	10485869	// Edit Assignment: "" (Edit)

/*
*/

// "Edit condition" Dialog Box (IDD_EDITCOND == 110)

#define IDH_110_185	12124270	// Edit condition: "Ignore" (Button)
#define IDH_110_186	12189806	// Edit condition: "Hold job" (Button)
#define IDH_110_176	11534446	// Edit condition: "=" (Button)
#define IDH_110_160	10485870	// Edit condition: "" (Edit)
#define IDH_110_184	12058734	// Edit condition: "" (ComboBox)

/*
*/

// "Edit environment variable" Dialog Box (IDD_EDITENV == 111)

#define IDH_111_187	12255343	// Edit environment variable: "" (Edit)
#define IDH_111_188	12320879	// Edit environment variable: "" (Edit)

/*
*/

// "Edit Format Code" Dialog Box (IDD_EDITFMT == 112)

#define IDH_112_189	12386416	// Edit Format Code: "" (ComboBox)
#define IDH_112_190	12451952	// Edit Format Code: "0" (Edit)
#define IDH_112_192	12583024	// Edit Format Code: "Tab format left if too long" (Button)
#define IDH_112_193	12648560	// Edit Format Code: "Skip fields to right if too long" (Button)

/*
*/

// "Edit Job Redirection" Dialog Box (IDD_EDITREDIR == 113)

#define IDH_113_208	13631601	// Edit Job Redirection: "Read" (Button)
#define IDH_113_209	13697137	// Edit Job Redirection: "Write" (Button)
#define IDH_113_210	13762673	// Edit Job Redirection: "Append" (Button)
#define IDH_113_194	12714097	// Edit Job Redirection: "0" (Edit)
#define IDH_113_196	12845169	// Edit Job Redirection: "" (Edit)
#define IDH_113_197	12910705	// Edit Job Redirection: "File" (Button)
#define IDH_113_198	12976241	// Edit Job Redirection: "Pipe out to" (Button)
#define IDH_113_199	13041777	// Edit Job Redirection: "Pipe in from" (Button)
#define IDH_113_200	13107313	// Edit Job Redirection: "Close" (Button)
#define IDH_113_201	13172849	// Edit Job Redirection: "Dup f.d." (Button)
#define IDH_113_202	13238385	// Edit Job Redirection: "0" (Edit)
#define IDH_113_204	13369457	// Edit Job Redirection: "" (Edit)
#define IDH_113_205	13434993	// Edit Job Redirection: "" (Edit)

/*
*/

// "New separator string" Dialog Box (IDD_EDITSEP == 114)

#define IDH_114_211	13828210	// New separator string: "" (Edit)

/*
*/

// "Job environment variables" Dialog Box (IDD_ENVLIST == 115)

#define IDH_115_212	13893747	// Job environment variables: "" (ListBox)
#define IDH_115_213	13959283	// Job environment variables: "New" (Button)
#define IDH_115_214	14024819	// Job environment variables: "Edit" (Button)
#define IDH_115_215	14090355	// Job environment variables: "Delete" (Button)

/*
*/

// "Set up formats" Dialog Box (IDD_FORMATDEF == 116)

#define IDH_116_216	14155892	// Set up formats: "" (Edit)
#define IDH_116_217	14221428	// Set up formats: "" (ListBox)
#define IDH_116_218	14286964	// Set up formats: "New" (Button)
#define IDH_116_219	14352500	// Set up formats: "New sep" (Button)
#define IDH_116_220	14418036	// Set up formats: "Edit" (Button)
#define IDH_116_221	14483572	// Set up formats: "Delete" (Button)
#define IDH_116_222	14549108	// Set up formats: "Reset Default format" (Button)

/*
*/

// "Job Assignments" Dialog Box (IDD_JASS == 117)

#define IDH_117_223	14614645	// Job Assignments: "" (ListBox)
#define IDH_117_224	14680181	// Job Assignments: "New" (Button)
#define IDH_117_225	14745717	// Job Assignments: "Edit" (Button)
#define IDH_117_226	14811253	// Job Assignments: "Delete" (Button)

/*
*/

// "Job conditions" Dialog Box (IDD_JCOND == 118)

#define IDH_118_227	14876790	// Job conditions: "" (ListBox)
#define IDH_118_228	14942326	// Job conditions: "New" (Button)
#define IDH_118_229	15007862	// Job conditions: "Edit" (Button)
#define IDH_118_230	15073398	// Job conditions: "Delete" (Button)

/*
*/

// "Job permissions / user / group" Dialog Box (IDD_JOBMODE == 120)

#define IDH_120_254	16646264	// Job permissions / user / group: "" (Button)
#define IDH_120_231	15138936	// Job permissions / user / group: "Read" (Button)
#define IDH_120_255	16711800	// Job permissions / user / group: "" (Button)
#define IDH_120_232	15204472	// Job permissions / user / group: "Write" (Button)
#define IDH_120_256	16777336	// Job permissions / user / group: "" (Button)
#define IDH_120_233	15270008	// Job permissions / user / group: "Reveal" (Button)
#define IDH_120_257	16842872	// Job permissions / user / group: "" (Button)
#define IDH_120_234	15335544	// Job permissions / user / group: "Display modes" (Button)
#define IDH_120_258	16908408	// Job permissions / user / group: "" (Button)
#define IDH_120_235	15401080	// Job permissions / user / group: "Set modes" (Button)
#define IDH_120_259	16973944	// Job permissions / user / group: "" (Button)
#define IDH_120_236	15466616	// Job permissions / user / group: "Assume ownership" (Button)
#define IDH_120_260	17039480	// Job permissions / user / group: "" (Button)
#define IDH_120_237	15532152	// Job permissions / user / group: "Assume group ownership" (Button)
#define IDH_120_261	17105016	// Job permissions / user / group: "" (Button)
#define IDH_120_238	15597688	// Job permissions / user / group: "Give away ownership" (Button)
#define IDH_120_262	17170552	// Job permissions / user / group: "" (Button)
#define IDH_120_239	15663224	// Job permissions / user / group: "Give away group" (Button)
#define IDH_120_263	17236088	// Job permissions / user / group: "" (Button)
#define IDH_120_240	15728760	// Job permissions / user / group: "Delete" (Button)
#define IDH_120_264	17301624	// Job permissions / user / group: "" (ComboBox)
#define IDH_120_241	15794296	// Job permissions / user / group: "Kill" (Button)
#define IDH_120_265	17367160	// Job permissions / user / group: "" (ComboBox)
#define IDH_120_242	15859832	// Job permissions / user / group: "" (Button)
#define IDH_120_243	15925368	// Job permissions / user / group: "" (Button)
#define IDH_120_244	15990904	// Job permissions / user / group: "" (Button)
#define IDH_120_245	16056440	// Job permissions / user / group: "" (Button)
#define IDH_120_246	16121976	// Job permissions / user / group: "" (Button)
#define IDH_120_247	16187512	// Job permissions / user / group: "" (Button)
#define IDH_120_248	16253048	// Job permissions / user / group: "" (Button)
#define IDH_120_249	16318584	// Job permissions / user / group: "" (Button)
#define IDH_120_250	16384120	// Job permissions / user / group: "" (Button)
#define IDH_120_251	16449656	// Job permissions / user / group: "" (Button)
#define IDH_120_252	16515192	// Job permissions / user / group: "" (Button)
#define IDH_120_253	16580728	// Job permissions / user / group: "" (Button)

/*
*/

// "Please log in to Unix Host...." Dialog Box (IDD_LOGINHOST == 121)

#define IDH_121_266	17432697	// Please log in to Unix Host....: "" (Edit)
#define IDH_121_267	17498233	// Please log in to Unix Host....: "" (Edit)
#define IDH_121_268	17563769	// Please log in to Unix Host....: "" (Edit)
#define IDH_121_269	17629305	// Please log in to Unix Host....: "" (Edit)

/*
*/

// "Mail/Write flags" Dialog Box (IDD_MAILWRITE == 122)

#define IDH_122_270	17694842	// Mail/Write flags: "Mail completion" (Button)
#define IDH_122_271	17760378	// Mail/Write flags: "Write completion" (Button)

/*
*/

// "Network Status" Dialog Box (IDD_NETSTATS == 123)

#define IDH_123_272	17825915	// Network Status: "" (ComboBox)
#define IDH_123_273	17891451	// Network Status: "Probe sent (or no probe required)" (Button)
#define IDH_123_274	17956987	// Network Status: "TCP Connection made" (Button)
#define IDH_123_275	18022523	// Network Status: "Sync Requested" (Button)
#define IDH_123_276	18088059	// Network Status: "Sync Completed" (Button)

/*
*/

// "Send kill signal" Dialog Box (IDD_OTHERSIG == 124)

#define IDH_124_277	18153596	// Send kill signal: "Hangup" (Button)
#define IDH_124_278	18219132	// Send kill signal: "Interrupt" (Button)
#define IDH_124_279	18284668	// Send kill signal: "Quit" (Button)
#define IDH_124_280	18350204	// Send kill signal: "Terminate" (Button)
#define IDH_124_281	18415740	// Send kill signal: "KILL" (Button)

/*
*/

// "Process parameters" Dialog Box (IDD_PROCPAR == 125)

#define IDH_125_302	19791997	// Process parameters: "Advance time" (Button)
#define IDH_125_303	19857533	// Process parameters: "Do not advance time" (Button)
#define IDH_125_304	19923069	// Process parameters: "Remote executable" (Button)
#define IDH_125_282	18481277	// Process parameters: "" (Edit)
#define IDH_125_283	18546813	// Process parameters: "R" (Button)
#define IDH_125_284	18612349	// Process parameters: "W" (Button)
#define IDH_125_285	18677885	// Process parameters: "X" (Button)
#define IDH_125_286	18743421	// Process parameters: "R" (Button)
#define IDH_125_287	18808957	// Process parameters: "W" (Button)
#define IDH_125_288	18874493	// Process parameters: "X" (Button)
#define IDH_125_289	18940029	// Process parameters: "R" (Button)
#define IDH_125_290	19005565	// Process parameters: "W" (Button)
#define IDH_125_291	19071101	// Process parameters: "X" (Button)
#define IDH_125_292	19136637	// Process parameters: "" (Edit)
#define IDH_125_294	19267709	// Process parameters: "0" (Edit)
#define IDH_125_298	19529853	// Process parameters: "0" (Edit)

/*
*/

// "Program options" Dialog Box (IDD_PROGOPTS == 126)

#define IDH_126_306	20054142	// Program options: "" (ComboBox)
#define IDH_126_307	20119678	// Program options: "Including empty" (Button)
#define IDH_126_309	20250750	// Program options: "Never" (Button)
#define IDH_126_310	20316286	// Program options: "Always" (Button)
#define IDH_126_264	17301630	// Program options: "" (ComboBox)
#define IDH_126_311	20381822	// Program options: "Ignore" (Button)
#define IDH_126_265	17367166	// Program options: "" (ComboBox)
#define IDH_126_312	20447358	// Program options: "Warn" (Button)
#define IDH_126_313	20512894	// Program options: "Display local host only" (Button)
#define IDH_126_314	20578430	// Program options: "Display all hosts" (Button)
#define IDH_126_315	20643966	// Program options: "0" (Edit)
#define IDH_126_317	20775038	// Program options: "Unqueue as binary" (Button)
#define IDH_126_318	20840574	// Program options: "XBC" (Button)
#define IDH_126_319	20906110	// Program options: "BAT" (Button)

/*
*/

// "Job redirections" Dialog Box (IDD_REDIRLIST == 127)

#define IDH_127_323	21168255	// Job redirections: "Delete" (Button)
#define IDH_127_320	20971647	// Job redirections: "" (ListBox)
#define IDH_127_321	21037183	// Job redirections: "New" (Button)
#define IDH_127_322	21102719	// Job redirections: "Edit" (Button)

/*
*/

// "Search job data" Dialog Box (IDD_SEARCHDATA == 128)

#define IDH_128_324	21233792	// Search job data: "" (Edit)
#define IDH_128_325	21299328	// Search job data: "Forward" (Button)
#define IDH_128_326	21364864	// Search job data: "Backward" (Button)
#define IDH_128_327	21430400	// Search job data: "Wrap Around" (Button)
#define IDH_128_328	21495936	// Search job data: "Ignore Case" (Button)

/*
*/

// "Search for job strings" Dialog Box (IDD_SEARCHJ == 129)

#define IDH_129_324	21233793	// Search for job strings: "" (Edit)
#define IDH_129_325	21299329	// Search for job strings: "Forward" (Button)
#define IDH_129_326	21364865	// Search for job strings: "Backward" (Button)
#define IDH_129_327	21430401	// Search for job strings: "Wrap Around" (Button)
#define IDH_129_329	21561473	// Search for job strings: "User" (Button)
#define IDH_129_330	21627009	// Search for job strings: "Job title" (Button)

/*
*/

// "Job time limits" Dialog Box (IDD_TIMELIMS == 130)

#define IDH_130_376	24641666	// Job time limits: "0" (Edit)
#define IDH_130_333	21823618	// Job time limits: "" (Edit)
#define IDH_130_382	25034882	// Job time limits: "OFF" (Button)
#define IDH_130_383	25100418	// Job time limits: "Sigterm" (Button)
#define IDH_130_391	25624706	// Job time limits: "" (Edit)

/*
*/

// "Set job time" Dialog Box (IDD_TIMER == 131)

#define IDH_131_346	22675587	// Set job time: "Run and retain" (Button)
#define IDH_131_370	24248451	// Set job time: "Skip" (Button)
#define IDH_131_347	22741123	// Set job time: "Minutes" (Button)
#define IDH_131_371	24313987	// Set job time: "Delay Current" (Button)
#define IDH_131_348	22806659	// Set job time: "Hours" (Button)
#define IDH_131_372	24379523	// Set job time: "Delay all" (Button)
#define IDH_131_349	22872195	// Set job time: "Days" (Button)
#define IDH_131_373	24445059	// Set job time: "Catch up" (Button)
#define IDH_131_350	22937731	// Set job time: "Weeks" (Button)
#define IDH_131_351	23003267	// Set job time: "Months (rel begin)" (Button)
#define IDH_131_375	24576131	// Set job time: "" (Edit)
#define IDH_131_352	23068803	// Set job time: "Months (rel end)" (Button)
#define IDH_131_353	23134339	// Set job time: "Years" (Button)
#define IDH_131_331	21692547	// Set job time: "Set time for job" (Button)
#define IDH_131_355	23265411	// Set job time: "0" (Edit)
#define IDH_131_333	21823619	// Set job time: "" (Edit)
#define IDH_131_358	23462019	// Set job time: "" (Edit)
#define IDH_131_361	23658627	// Set job time: "Sun" (Button)
#define IDH_131_345	22610051	// Set job time: "Run and delete" (Button)

/*
*/

// "Title Command Int Priority Load level" Dialog Box (IDD_TITLEPRIO == 132)

#define IDH_132_395	25886852	// Title Command Int Priority Load level: "" (Edit)
#define IDH_132_396	25952388	// Title Command Int Priority Load level: "" (ComboBox)
#define IDH_132_397	26017924	// Title Command Int Priority Load level: "0" (Edit)
#define IDH_132_399	26148996	// Title Command Int Priority Load level: "0" (Edit)

/*
*/

// "User Permissions" Dialog Box (IDD_USERPERM == 133)

#define IDH_133_401	26280069	// User Permissions: "Read admin" (Button)
#define IDH_133_264	17301637	// User Permissions: "" (Edit)
#define IDH_133_265	17367173	// User Permissions: "" (Edit)
#define IDH_133_410	26869893	// User Permissions: "" (Edit)
#define IDH_133_411	26935429	// User Permissions: "" (Edit)
#define IDH_133_412	27000965	// User Permissions: "" (Edit)

/*
*/

// "Assign Variable" Dialog Box (IDD_VARASS == 134)

#define IDH_134_415	27197574	// Assign Variable: "" (Edit)
#define IDH_134_413	27066502	// Assign Variable: "" (Edit)
#define IDH_134_414	27132038	// Assign Variable: "" (Edit)

/*
*/

// "Variable Comment" Dialog Box (IDD_VARCOMM == 135)

#define IDH_135_417	27328647	// Variable Comment: "" (Edit)
#define IDH_135_413	27066503	// Variable Comment: "" (Edit)

/*
*/

// "Variable permissions / user /group" Dialog Box (IDD_VARMODE == 136)

#define IDH_136_418	27394184	// Variable permissions / user /group: "Read" (Button)
#define IDH_136_264	17301640	// Variable permissions / user /group: "" (ComboBox)
#define IDH_136_265	17367176	// Variable permissions / user /group: "" (ComboBox)

/*
*/

// "Search for variable" Dialog Box (IDD_VSEARCH == 137)

#define IDH_137_324	21233801	// Search for variable: "" (Edit)
#define IDH_137_325	21299337	// Search for variable: "Forward" (Button)
#define IDH_137_326	21364873	// Search for variable: "Backward" (Button)
#define IDH_137_327	21430409	// Search for variable: "Wrap Around" (Button)
#define IDH_137_329	21561481	// Search for variable: "User" (Button)
#define IDH_137_448	29360265	// Search for variable: "Variable name" (Button)
#define IDH_137_449	29425801	// Search for variable: "Value" (Button)
#define IDH_137_450	29491337	// Search for variable: "Comment" (Button)

/*
*/

// "Window Options" Dialog Box (IDD_WINOPTS == 138)

#define IDH_138_306	20054154	// Window Options: "" (ComboBox)
#define IDH_138_307	20119690	// Window Options: "Including empty" (Button)
#define IDH_138_309	20250762	// Window Options: "Never" (Button)
#define IDH_138_310	20316298	// Window Options: "Always" (Button)
#define IDH_138_264	17301642	// Window Options: "" (ComboBox)
#define IDH_138_265	17367178	// Window Options: "" (ComboBox)
#define IDH_138_313	20512906	// Window Options: "Display local host only" (Button)
#define IDH_138_314	20578442	// Window Options: "Display all hosts" (Button)

/*
*/

// "New" Dialog Box


/*
const DWORD a30721HelpIDs[]=
{
	0, 0
};
*/

extern	BOOL	do_contexthelp(const UINT, const DWORD *);
