// Advise that net messages have arrived.
// ARRIVED is generated by the Winsock stuff and sent to the main frame
// The others are caught by the relevant child windows

#define	WM_NETMSG_ARRIVED	(WM_USER + 101)
#define	WM_NETMSG_JADD		(WM_USER + 102)
#define	WM_NETMSG_JCHANGE	(WM_USER + 103)
#define	WM_NETMSG_JDEL		(WM_USER + 104)
#define	WM_NETMSG_JREVISED	(WM_USER + 105)
#define	WM_NETMSG_VADD		(WM_USER + 106)
#define	WM_NETMSG_VCHANGE	(WM_USER + 107)
#define	WM_NETMSG_VDEL		(WM_USER + 108)
#define	WM_NETMSG_VREVISED	(WM_USER + 109)
#define WM_NETMSG_NEWCONN	(WM_USER + 110)
#define WM_NETMSG_PROBERCV	(WM_USER + 111)
#define	WM_NETMSG_MESSAGE	(WM_USER + 112)
#define	WM_NETMSG_TICKLE	(WM_USER + 113)

extern	UINT		initsockets();
extern	void		attach_hosts(void);

extern	void	net_recvmsg(WPARAM, LPARAM);
extern	void	net_recvconn(WPARAM, LPARAM);
extern	void	net_recvprobe(WPARAM, LPARAM);
extern	void	reply_probe(void);
extern	void	netsync(void);
extern	void	netshut(void);

void	job_sendupdate(const Btjob &, const unsigned);
void	job_sendmdupdate(const Btjob &, const Btjob &);
void	job_sendugupdate(const Btjob &, const unsigned, const CString &);
void	job_message(const Btjob &, const unsigned, const unsigned long = 0L);
void	var_sendupdate(const Btvar &, const Btvar &, const unsigned);
void	var_sendugupdate(const Btvar &, const unsigned, const CString &);


