/* argcodes.h -- argument codes

   Copyright 2009 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#define	ARG_BTR_EXPLAIN		100
#define	ARG_BTR_NOVERBOSE	101
#define	ARG_BTR_VERBOSE		102
#define	ARG_BTR_MAIL		103
#define	ARG_BTR_WRITE		104
#define	ARG_BTR_TITLE		105
#define	ARG_BTR_CANCMAILWRITE	106
#define	ARG_BTR_INTERPRETER	107
#define	ARG_BTR_PRIORITY	108
#define	ARG_BTR_LOADLEV		109
#define	ARG_BTR_MODE		110
#define	ARG_BTR_NORMAL		111
#define	ARG_BTR_ASCANC		112
#define	ARG_BTR_NOTIME		113
#define	ARG_BTR_TIME		114
#define	ARG_BTR_NOREPEAT	115
#define	ARG_BTR_DELETEATEND	116
#define	ARG_BTR_REPEAT		117
#define	ARG_BTR_AVOIDING	118
#define	ARG_BTR_SKIP		119
#define	ARG_BTR_HOLD		120
#define	ARG_BTR_RESCHED		121
#define	ARG_BTR_CANCIO		122
#define	ARG_BTR_IO		123
#define	ARG_BTR_DIRECTORY	124
#define	ARG_BTR_CANCARGS	125
#define	ARG_BTR_ARGUMENT	126
#define	ARG_BTR_CANCCOND	127
#define	ARG_BTR_CONDITION	128
#define	ARG_BTR_CANCSET		129
#define	ARG_BTR_FLAGS		130
#define	ARG_BTR_SET		131
#define	ARG_BTR_UMASK		132
#define	ARG_BTR_ULIMIT		133
#define	ARG_BTR_EXITS		134
#define	ARG_BTR_AVTERR		135
#define	ARG_BTR_NOAVTERR	136
#define	ARG_BTR_OWNER		137
#define	ARG_BTR_GROUP		138
#define	ARG_BTR_NOEXPORT	139
#define	ARG_BTR_EXPORT		140
#define	ARG_BTR_FULLEXPORT	141
#define	ARG_BTR_CONDCRIT	142
#define	ARG_BTR_NOCONDCRIT	143
#define	ARG_BTR_ASSCRIT		144
#define	ARG_BTR_NOASSCRIT	145
#define	ARG_BTR_JOBQUEUE	146
#define	ARG_BTR_DELTIME		147
#define	ARG_BTR_RUNTIME		148
#define	ARG_BTR_WHICHSIG	149
#define	ARG_BTR_GRACETIME	150
#define	ARG_BTR_ASDONE		151
#define	ARG_BTR_BINMODE		152
#define	ARG_BTR_TEXTMODE	153
#define	LARGEST_BTR_ARG		ARG_BTR_TEXTMODE
#define	ARG_BTR_FREEZE		154
