// stdafx.h : include file for standard system include files,
//  or project specific include files that are used frequently, but
//		are changed infrequently
//

#include <afxwin.h>			// MFC core and standard components
#include <afxcmn.h>
#include <afxext.h>
#include <afxadv.h>
#include <winsock.h>
#include "defs.h"
#include "bjparam.h"
#include "btmode.h"
#include "btuser.h"
#include "options.h"
#include "cmdint.h"
#include "btconst.h"
#include "timecon.h"
#include "xbnetq.h"
