//Microsoft Developer Studio generated resource script.
//
#include "resource.h"

// Generated Help ID header file
#define APSTUDIO_HIDDEN_SYMBOLS
#include "resource.hm"
#undef APSTUDIO_HIDDEN_SYMBOLS

#define APSTUDIO_READONLY_SYMBOLS
/////////////////////////////////////////////////////////////////////////////
//
// Generated from the TEXTINCLUDE 2 resource.
//
#include "afxres.h"

/////////////////////////////////////////////////////////////////////////////
#undef APSTUDIO_READONLY_SYMBOLS

/////////////////////////////////////////////////////////////////////////////
// English (U.K.) resources

#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENG)
#ifdef _WIN32
LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_UK
#pragma code_page(1252)
#endif //_WIN32

#ifdef APSTUDIO_INVOKED
/////////////////////////////////////////////////////////////////////////////
//
// TEXTINCLUDE
//

1 TEXTINCLUDE DISCARDABLE 
BEGIN
    "resource.h\0"
END

2 TEXTINCLUDE DISCARDABLE 
BEGIN
    "#include ""afxres.h""\r\n"
    "\0"
END

3 TEXTINCLUDE DISCARDABLE 
BEGIN
    "#include ""res\\btrw.rc2""  // non-App Studio edited resources\r\n"
    "\r\n"
    "#include ""afxres.rc""  \t// Standard components\r\n"
    "\0"
END

#endif    // APSTUDIO_INVOKED


/////////////////////////////////////////////////////////////////////////////
//
// Icon
//

// Icon with lowest ID value placed first to ensure application icon
// remains consistent on all systems.
IDR_MAINFRAME           ICON    DISCARDABLE     "RES\\BTRW.ICO"

/////////////////////////////////////////////////////////////////////////////
//
// Bitmap
//

IDR_MAINFRAME           BITMAP  MOVEABLE PURE   "RES\\TOOLBAR.BMP"

/////////////////////////////////////////////////////////////////////////////
//
// Menu
//

IDR_MAINFRAME MENU PRELOAD DISCARDABLE 
BEGIN
    POPUP "&File"
    BEGIN
        MENUITEM "&New\tCtrl+N",                ID_FILE_NEW
        MENUITEM "&Delete job\tDEL",            ID_ACTION_DELETEJOB
        MENUITEM "&Open...\tCtrl+O",            ID_FILE_OPEN
        MENUITEM "&Save\tCtrl+S",               ID_FILE_SAVE
        MENUITEM "Save &As...",                 ID_FILE_SAVE_AS
        MENUITEM SEPARATOR
        MENUITEM "Recent File",                 ID_FILE_MRU_FILE1, GRAYED
        MENUITEM SEPARATOR
        MENUITEM "&Program options\tCtrl+P",    ID_FILE_PROGRAMOPTIONS
        MENUITEM "Save De&faults",              ID_FILE_SAVEDEFAULTS
        MENUITEM SEPARATOR
        MENUITEM "&User Permissions",           ID_FILE_USERPERMISSIONS
        MENUITEM SEPARATOR
        MENUITEM "E&xit",                       ID_APP_EXIT
    END
    POPUP "&Defaults"
    BEGIN
        MENUITEM "Set runnable\tR",             ID_DEFAULTS_SETRUNNABLE
        MENUITEM "Set cancelled\tZ",            ID_DEFAULTS_SETCANCELLED
        MENUITEM SEPARATOR
        MENUITEM "&Time\tt",                    ID_DEFAULTS_TIME
        MENUITEM "Title pri/&loadlev\tp",       ID_DEFAULTS_TITLEPRILOADLEV
        MENUITEM "&Process parameters",         ID_DEFAULTS_PROCPARAM
        MENUITEM "Time &Limits",                ID_DEFAULTS_TIMELIMITS
        MENUITEM "Per&missions",                ID_DEFAULTS_PERMISSIONS
        MENUITEM "Mail and &write",             ID_DEFAULTS_MAIL
        MENUITEM SEPARATOR
        MENUITEM "&Arguments",                  ID_DEFAULTS_ARGUMENTS
        MENUITEM "&Redirections",               ID_DEFAULTS_REDIRECTIONS
        MENUITEM "&Conditions",                 ID_DEFAULTS_CONDITIONS
        MENUITEM "A&ssignments",                ID_DEFAULTS_ASSIGNMENTS
        MENUITEM SEPARATOR
        MENUITEM "N&ew conditions",             ID_DEFAULTS_NEWCONDITIONS
        MENUITEM "Ne&w assignments",            ID_DEFAULTS_NEWASSIGNMENTS
    END
    POPUP "&Action"
    BEGIN
        MENUITEM "Name or C&opy job file",      ID_ACTION_COPYJOBFILE
        MENUITEM SEPARATOR
        MENUITEM "&Edit job\tE",                ID_JOBS_EDITJOB
        MENUITEM SEPARATOR
        MENUITEM "&Submit job\tS",              ID_ACTION_SUBMITJOB
        MENUITEM SEPARATOR
        MENUITEM "Set &runnable\tr",            ID_ACTION_SETRUNNABLE
        MENUITEM "Set &cancelled\tz",           ID_ACTION_SETCANCELLED
        MENUITEM "Set &done\td",                ID_ACTION_SETDONE
    END
    POPUP "&Jobs"
    BEGIN
        MENUITEM "&Time\tt",                    ID_JOBS_TIME
        MENUITEM "&Title pri/loadlev\tp",       ID_ACTION_TITLEPRILOADLEV
        MENUITEM "&Process parameters",         ID_JOBS_PROCPARAM
        MENUITEM "Time &Limits",                ID_JOBS_TIMELIMITS
        MENUITEM "Per&missions",                ID_ACTION_PERMISSIONS
        MENUITEM "Mail and &write",             ID_JOBS_MAIL
    END
    POPUP "&Environment"
    BEGIN
        MENUITEM "Environment &Default",        ID_ENVIRONMENT_ENVIRONMENTDEFAULT

        MENUITEM "&Clear Environment",          ID_ENVIRONMENT_CLEARENVIRONMENT

        MENUITEM "&Edit Environment",           ID_JOBS_ENVIRONMENT
        MENUITEM "S&queeze Environment",        ID_ENVIRONMENT_SQUEEZEENVIRONMENT

        MENUITEM SEPARATOR
        MENUITEM "&Arguments",                  ID_JOBS_ARGUMENTS
        MENUITEM "&Redirections",               ID_JOBS_REDIRECTIONS
    END
    POPUP "&Conditions"
    BEGIN
        MENUITEM "Job &Conditions\tC",          ID_CONDITIONS_JOBCONDITIONS
        MENUITEM "Job &Assignments\tS",         ID_CONDITIONS_JOBASSIGNMENTS
    END
    POPUP "&View"
    BEGIN
        MENUITEM "&Toolbar",                    ID_VIEW_TOOLBAR
        MENUITEM "&Status Bar",                 ID_VIEW_STATUS_BAR
    END
    POPUP "&Help"
    BEGIN
        MENUITEM "&Index",                      ID_HELP_INDEX
        MENUITEM "&Using Help",                 ID_HELP_USING
        MENUITEM SEPARATOR
        MENUITEM "&About Btrw...",              ID_APP_ABOUT
    END
END


/////////////////////////////////////////////////////////////////////////////
//
// Accelerator
//

IDR_MAINFRAME ACCELERATORS PRELOAD MOVEABLE PURE 
BEGIN
    "C",            ID_CONDITIONS_JOBCONDITIONS, VIRTKEY, SHIFT, NOINVERT
    "C",            ID_CONDITIONS_JOBCONDITIONS, VIRTKEY, SHIFT, NOINVERT
    "D",            ID_ACTION_SETDONE,      VIRTKEY, NOINVERT
    "E",            ID_JOBS_EDITJOB,        VIRTKEY, SHIFT, NOINVERT
    "N",            ID_FILE_NEW,            VIRTKEY, CONTROL, NOINVERT
    "O",            ID_FILE_OPEN,           VIRTKEY, CONTROL, NOINVERT
    "P",            ID_ACTION_TITLEPRILOADLEV, VIRTKEY, NOINVERT
    "P",            ID_FILE_PROGRAMOPTIONS, VIRTKEY, CONTROL, NOINVERT
    "R",            ID_ACTION_SETRUNNABLE,  VIRTKEY, NOINVERT
    "R",            ID_DEFAULTS_SETRUNNABLE, VIRTKEY, SHIFT, NOINVERT
    "S",            ID_FILE_SAVE,           VIRTKEY, CONTROL, NOINVERT
    "S",            ID_ACTION_SUBMITJOB,    VIRTKEY, SHIFT, NOINVERT
    "T",            ID_JOBS_TIME,           VIRTKEY, NOINVERT
    VK_DELETE,      ID_ACTION_DELETEJOB,    VIRTKEY, NOINVERT
    VK_F1,          ID_HELP,                VIRTKEY, NOINVERT
    VK_F1,          ID_CONTEXT_HELP,        VIRTKEY, SHIFT, NOINVERT
    VK_F6,          ID_NEXT_PANE,           VIRTKEY, NOINVERT
    VK_F6,          ID_PREV_PANE,           VIRTKEY, SHIFT, NOINVERT
    "Z",            ID_ACTION_SETCANCELLED, VIRTKEY, NOINVERT
    "Z",            ID_DEFAULTS_SETCANCELLED, VIRTKEY, SHIFT, NOINVERT
END


/////////////////////////////////////////////////////////////////////////////
//
// Dialog
//

IDD_ABOUTBOX DIALOG DISCARDABLE  34, 22, 217, 55
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "About Btrw"
FONT 8, "MS Sans Serif"
BEGIN
    ICON            IDR_MAINFRAME,IDC_STATIC,11,17,20,20
    CTEXT           "Btrw Submit jobs Version 6.12",IDC_STATIC,40,10,128,8
    CTEXT           "Copyright Xi Software Ltdİ 2003",IDC_STATIC,40,24,128,8
    DEFPUSHBUTTON   "OK",IDOK,176,6,32,14,WS_GROUP
    CTEXT           "Revised 19 February 2003",IDC_STATIC,40,38,128,8
END

IDD_PROGOPTS DIALOGEX 0, 0, 192, 171
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Program options"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    CTEXT           "Job script editor",IDC_STATIC,44,12,94,12
    EDITTEXT        IDC_JEDITOR,16,36,140,12,ES_AUTOHSCROLL,0,HIDC_JEDITOR
    CONTROL         "Binary job files",IDC_BINMODE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,14,63,132,10,0,HIDC_BINMODE
    CONTROL         "Verbose (display result)",IDC_VERBOSE,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,14,80,132,10,0,HIDC_VERBOSE
    LTEXT           "Queue",IDC_STATIC,14,118,30,7
    EDITTEXT        IDC_JOBQUEUE,52,116,112,12,ES_AUTOHSCROLL,0,
                    HIDC_JOBQUEUE
    DEFPUSHBUTTON   "OK",IDOK,8,144,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,130,144,50,14
    CONTROL         "Created jobs NOT exported",IDC_NONEXPORT,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,14,97,128,10,0,
                    HIDC_NONEXPORT
END

IDD_NEWJOBFILE DIALOG DISCARDABLE  0, 0, 55, 18
STYLE DS_MODALFRAME | WS_POPUP | WS_VISIBLE | WS_CAPTION | WS_SYSMENU
CAPTION "Dialog"
FONT 8, "MS Sans Serif"
BEGIN
END

IDD_COPYJOBFILE DIALOG DISCARDABLE  0, 0, 39, 18
STYLE DS_MODALFRAME | WS_POPUP | WS_VISIBLE | WS_CAPTION | WS_SYSMENU
CAPTION "Dialog"
FONT 8, "MS Sans Serif"
BEGIN
END

IDD_TIMER DIALOGEX 0, 0, 287, 246
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Set job time"
FONT 8, "MS Sans Serif", 0, 0, 0x1
BEGIN
    CONTROL         "Set time for job",IDC_TIMEISSET,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,12,8,92,10,0,HIDC_TIMEISSET
    EDITTEXT        IDC_HOUR,7,24,31,14,ES_READONLY | ES_NUMBER,0,HIDC_HOUR
    CONTROL         "Spin1",IDC_SCR_HOUR,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,33,24,9,14,0,HIDC_SCR_HOUR
    LTEXT           ":",IDC_COLON,44,27,2,8,0,0,HIDC_COLON
    EDITTEXT        IDC_MIN,48,24,31,14,ES_READONLY | ES_NUMBER,0,HIDC_MIN
    CONTROL         "Spin2",IDC_SCR_MIN,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,74,24,9,14,0,HIDC_SCR_MIN
    EDITTEXT        IDC_WDAY,91,24,54,14,ES_READONLY,0,HIDC_WDAY
    CONTROL         "Spin7",IDC_SCR_WDAY,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,137,24,9,14,0,
                    HIDC_SCR_WDAY
    EDITTEXT        IDC_MDAY,147,24,31,14,ES_READONLY,0,HIDC_MDAY
    CONTROL         "Spin8",IDC_SCR_MDAY,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,167,24,9,14,0,
                    HIDC_SCR_MDAY
    EDITTEXT        IDC_MON,180,24,64,14,ES_READONLY,0,HIDC_MON
    CONTROL         "Spin9",IDC_SCR_MON,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,235,24,9,14,0,HIDC_SCR_MON
    EDITTEXT        IDC_YEAR,246,24,31,14,ES_READONLY,0,HIDC_YEAR
    CONTROL         "Spin10",IDC_SCR_YEAR,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,271,24,9,14,0,
                    HIDC_SCR_YEAR
    CONTROL         "Run and delete",IDC_DELETE,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,80,40,76,10,0,HIDC_DELETE
    CONTROL         "Run and retain",IDC_RETAIN,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,52,84,10,0,HIDC_RETAIN
    GROUPBOX        "Repeat every",IDC_MESS_REPEATEVERY,12,60,156,100
    EDITTEXT        IDC_REPEAT,19,83,34,12,ES_AUTOHSCROLL | ES_NUMBER,0,
                    HIDC_REPEAT
    CONTROL         "Spin1",IDC_SCR_REPEAT,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,57,82,9,14,0,HIDC_SCR_REPEAT
    CONTROL         "Minutes",IDC_REPMINS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,72,40,10,0,HIDC_REPMINS
    CONTROL         "Hours",IDC_REPHOURS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,84,34,10,0,HIDC_REPHOURS
    CONTROL         "Days",IDC_REPDAYS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,96,34,10,0,HIDC_REPDAYS
    CONTROL         "Weeks",IDC_REPWEEKS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,108,34,10,0,HIDC_REPWEEKS
    CONTROL         "Months (rel begin)",IDC_REPMONTHSB,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,80,120,72,10,0,
                    HIDC_REPMONTHSB
    CONTROL         "Months (rel end)",IDC_REPMONTHSE,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,80,132,76,10,0,
                    HIDC_REPMONTHSE
    CONTROL         "Years",IDC_REPYEARS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,144,34,10,0,HIDC_REPYEARS
    LTEXT           "Month day",IDC_MONDAYNAME,24,108,44,8
    EDITTEXT        IDC_MONTHDAY,19,131,34,12,ES_AUTOHSCROLL | ES_NUMBER,0,
                    HIDC_MONTHDAY
    CONTROL         "Spin2",IDC_SCR_MONTHDAY,"msctls_updown32",
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS,57,130,9,
                    14,0,HIDC_SCR_MONTHDAY
    GROUPBOX        "Avoiding...",IDC_MESS_AVOIDING,172,60,96,60
    CONTROL         "Sun",IDC_AVSUN,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    176,72,34,10,0,HIDC_AVSUN
    CONTROL         "Mon",IDC_AVMON,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    176,85,34,8,0,HIDC_AVMON
    CONTROL         "Tue",IDC_AVTUE,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    176,96,34,10,0,HIDC_AVTUE
    CONTROL         "Wed",IDC_AVWED,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    176,108,34,10,0,HIDC_AVWED
    CONTROL         "Thur",IDC_AVTHU,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    220,72,34,10,0,HIDC_AVTHU
    CONTROL         "Fri",IDC_AVFRI,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    220,84,34,10,0,HIDC_AVFRI
    CONTROL         "Sat",IDC_AVSAT,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    220,96,34,10,0,HIDC_AVSAT
    CONTROL         "Holiday",IDC_AVHOLIDAY,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,220,108,40,10,0,HIDC_AVHOLIDAY
    LTEXT           "Next repeat comes to....",IDC_MESS_COMESTO,148,168,88,8
    EDITTEXT        IDC_REPRESULT,120,184,144,12,ES_AUTOHSCROLL | 
                    ES_READONLY,0,HIDC_REPRESULT
    GROUPBOX        "If not possible",IDC_MESS_NOTPOSS,12,164,83,76
    CONTROL         "Skip",IDC_NPSKIP,"Button",BS_AUTORADIOBUTTON | WS_GROUP | 
                    WS_TABSTOP,16,180,34,10,0,HIDC_NPSKIP
    CONTROL         "Delay Current",IDC_NPDELCURR,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,16,194,72,10,0,
                    HIDC_NPDELCURR
    CONTROL         "Delay all",IDC_NPDELALL,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,16,208,57,10,0,HIDC_NPDELALL
    CONTROL         "Catch up",IDC_NPCATCHUP,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,16,222,57,10,0,HIDC_NPCATCHUP
    DEFPUSHBUTTON   "OK",IDOK,120,204,40,14
    PUSHBUTTON      "Cancel",IDCANCEL,224,204,40,14
END

IDD_ARGLIST DIALOGEX 0, 0, 232, 131
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job Argument List"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_ARGLIST,12,16,172,72,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_ARGLIST
    PUSHBUTTON      "New",IDC_NEWARG,192,12,35,14,0,0,HIDC_NEWARG
    PUSHBUTTON      "Edit",IDC_EDITARG,192,43,35,14,0,0,HIDC_EDITARG
    PUSHBUTTON      "Delete",IDC_DELARG,192,74,35,14,0,0,HIDC_DELARG
    DEFPUSHBUTTON   "OK",IDOK,12,108,35,14
    PUSHBUTTON      "Cancel",IDCANCEL,192,108,35,14
END

IDD_DEFASS DIALOGEX 0, 0, 252, 199
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Assignment defaults"
FONT 8, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Value",IDC_STATIC,17,9,39,10
    EDITTEXT        IDC_VALUE,68,8,148,12,ES_AUTOHSCROLL,0,HIDC_VALUE
    CONTROL         "Spin1",IDC_SCR_VALUE,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,221,7,9,14,0,
                    HIDC_SCR_VALUE
    GROUPBOX        "Assignment type",IDC_STATIC,4,40,129,86
    CONTROL         "Set",IDC_ASET,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_GROUP | WS_TABSTOP,24,58,25,15,0,HIDC_ASET
    CONTROL         "+",IDC_AADD,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,24,81,25,15,0,HIDC_AADD
    CONTROL         "-",IDC_ASUB,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,24,106,25,15,0,HIDC_ASUB
    CONTROL         "X",IDC_AMULT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,57,58,25,15,0,HIDC_AMULT
    CONTROL         "/",IDC_ADIV,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,57,81,25,15,0,HIDC_ADIV
    CONTROL         "Md",IDC_AMOD,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,57,106,25,15,0,HIDC_AMOD
    CONTROL         "Exit",IDC_AEXIT,"Button",BS_AUTORADIOBUTTON | 
                    BS_LEFTTEXT | WS_TABSTOP,87,58,35,15,0,HIDC_AEXIT
    CONTROL         "Sig",IDC_ASIGNAL,"Button",BS_AUTORADIOBUTTON | 
                    BS_LEFTTEXT | WS_TABSTOP,87,81,35,15,0,HIDC_ASIGNAL
    GROUPBOX        "If host unavailable",IDC_STATIC,4,133,126,60
    CONTROL         "Ignore",IDC_ANOTCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,11,152,58,15,0,HIDC_ANOTCRIT
    CONTROL         "Hold job",IDC_ACRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,11,170,99,15,0,HIDC_ACRIT
    CONTROL         "On start",IDC_ASTART,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,40,46,11,0,HIDC_ASTART
    CONTROL         "REVERSE on exit",IDC_AREVERSE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,56,85,12,0,HIDC_AREVERSE
    CONTROL         "Normal exit",IDC_ANORMAL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,73,61,10,0,HIDC_ANORMAL
    CONTROL         "Error exit",IDC_AERROR,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,88,61,12,0,HIDC_AERROR
    CONTROL         "Abort",IDC_AABORT,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    161,105,61,12,0,HIDC_AABORT
    CONTROL         "Cancel",IDC_ACANCEL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,122,61,12,0,HIDC_ACANCEL
    DEFPUSHBUTTON   "OK",IDOK,190,150,44,17
    PUSHBUTTON      "Cancel",IDCANCEL,190,176,44,17
END

IDD_DEFCONDOPT DIALOGEX 0, 0, 236, 115
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Condition defaults"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    EDITTEXT        IDC_VALUE,12,12,113,13,ES_AUTOHSCROLL,0,HIDC_VALUE
    CONTROL         "Spin1",IDC_SCR_VALUE,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,130,11,7,14,0,
                    HIDC_SCR_VALUE
    LTEXT           "Value",IDC_STATIC,151,13,40,10
    GROUPBOX        "Comparison",IDC_STATIC,12,40,73,70
    CONTROL         "=",IDC_CEQ,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_GROUP | WS_TABSTOP,28,55,19,12,0,HIDC_CEQ
    CONTROL         "!=",IDC_CNE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,28,74,19,12,0,HIDC_CNE
    CONTROL         "<",IDC_CLT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,28,94,19,12,0,HIDC_CLT
    CONTROL         "<=",IDC_CLE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,55,19,12,0,HIDC_CLE
    CONTROL         ">",IDC_CGT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,74,19,12,0,HIDC_CGT
    CONTROL         ">=",IDC_CGE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,94,19,12,0,HIDC_CGE
    GROUPBOX        "If host unavailable",IDC_STATIC,92,44,98,49
    CONTROL         "Ignore",IDC_CNOTCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,97,58,45,12,0,HIDC_CNOTCRIT
    CONTROL         "Hold job",IDC_CCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,97,73,77,12,0,HIDC_CCRIT
    DEFPUSHBUTTON   "OK",IDOK,196,16,36,17
    PUSHBUTTON      "Cancel",IDCANCEL,196,40,36,17
END

IDD_EDITARG DIALOGEX 0, 0, 184, 63
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit Argument"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    EDITTEXT        IDC_ARGVAL,4,12,176,13,ES_AUTOHSCROLL,0,HIDC_ARGVAL
    DEFPUSHBUTTON   "OK",IDOK,4,40,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,130,40,50,14
END

IDD_EDITASS DIALOGEX 0, 0, 236, 171
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit Assignment"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Variable",IDC_STATIC,32,4,30,8
    LTEXT           "Value",IDC_STATIC,144,4,30,8
    COMBOBOX        IDC_ASSVAR,12,20,82,64,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_ASSVAR
    EDITTEXT        IDC_VALUE,104,20,116,12,ES_AUTOHSCROLL,0,HIDC_ADIV
    CONTROL         "Spin1",IDC_SCR_VALUE,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,222,19,10,14,0,HIDC_AMOD
    GROUPBOX        "Assignment type",IDC_STATIC,12,40,100,70
    CONTROL         "Set",IDC_ASET,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_GROUP | WS_TABSTOP,27,55,19,12,0,HIDC_AEXIT
    CONTROL         "+",IDC_AADD,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,27,74,19,12,0,HIDC_ASIGNAL
    CONTROL         "-",IDC_ASUB,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,27,94,19,12,0,HIDC_ASUB
    CONTROL         "X",IDC_AMULT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,55,19,12,0,HIDC_AMULT
    CONTROL         "/",IDC_ADIV,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,74,19,12,0,HIDC_ADIV
    CONTROL         "Md",IDC_AMOD,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,94,19,12,0,HIDC_AMOD
    CONTROL         "Exit",IDC_AEXIT,"Button",BS_AUTORADIOBUTTON | 
                    BS_LEFTTEXT | WS_TABSTOP,76,55,27,12,0,HIDC_AEXIT
    CONTROL         "Sig",IDC_ASIGNAL,"Button",BS_AUTORADIOBUTTON | 
                    BS_LEFTTEXT | WS_TABSTOP,76,74,27,12,0,HIDC_ASIGNAL
    GROUPBOX        "If host unavailable",IDC_STATIC,12,116,98,49
    CONTROL         "Ignore",IDC_ANOTCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,17,131,45,12,0,HIDC_ANOTCRIT
    CONTROL         "Hold job",IDC_ACRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,17,146,77,12,0,HIDC_ACRIT
    CONTROL         "On start",IDC_ASTART,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,52,36,9,0,HIDC_ASTART
    CONTROL         "REVERSE on exit",IDC_AREVERSE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,65,66,10,0,HIDC_AREVERSE
    CONTROL         "Normal exit",IDC_ANORMAL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,79,47,8,0,HIDC_ANORMAL
    CONTROL         "Error exit",IDC_AERROR,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,91,47,10,0,HIDC_AERROR
    CONTROL         "Abort",IDC_AABORT,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    136,105,47,10,0,HIDC_AABORT
    CONTROL         "Cancel",IDC_ACANCEL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,119,47,10,0,HIDC_ACANCEL
    DEFPUSHBUTTON   "OK",IDOK,130,145,45,17
    PUSHBUTTON      "Cancel",IDCANCEL,185,145,45,17
END

IDD_EDITCOND DIALOGEX 0, 0, 196, 124
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit condition"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    COMBOBOX        IDC_CONDVAR,8,8,64,48,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_CONDVAR
    LTEXT           "Variable",IDC_STATIC,80,12,31,8
    EDITTEXT        IDC_VALUE,8,32,88,13,ES_AUTOHSCROLL,0,HIDC_VALUE
    CONTROL         "Spin1",IDC_SCR_VALUE,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,99,31,10,14,0,
                    HIDC_SCR_VALUE
    LTEXT           "Value",IDC_STATIC,120,34,31,8
    GROUPBOX        "Comparison",IDC_STATIC,8,60,57,57
    CONTROL         "=",IDC_CEQ,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_GROUP | WS_TABSTOP,20,72,15,10,0,HIDC_CEQ
    CONTROL         "!=",IDC_CNE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,20,88,15,10,0,HIDC_CNE
    CONTROL         "<",IDC_CLT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,20,104,15,10,0,HIDC_CLT
    CONTROL         "<=",IDC_CLE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,40,72,15,10,0,HIDC_CLE
    CONTROL         ">",IDC_CGT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,40,88,15,10,0,HIDC_CGT
    CONTROL         ">=",IDC_CGE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,40,104,15,10,0,HIDC_CGE
    GROUPBOX        "If host unavailable",IDC_STATIC,84,76,76,40
    CONTROL         "Ignore",IDC_CNOTCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,88,88,35,10,0,HIDC_CNOTCRIT
    CONTROL         "Hold job",IDC_CCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,88,100,60,10,0,HIDC_CCRIT
    DEFPUSHBUTTON   "OK",IDOK,156,7,35,14
    PUSHBUTTON      "Cancel",IDCANCEL,156,31,35,14
END

IDD_EDITENV DIALOGEX 0, 0, 268, 75
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit environment variable"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Name",IDC_STATIC,4,12,34,8
    EDITTEXT        IDC_ENAME,44,9,40,13,ES_AUTOHSCROLL,0,HIDC_ENAME
    LTEXT           "Value",IDC_STATIC,4,32,33,9
    EDITTEXT        IDC_EVALUE,44,30,220,12,ES_AUTOHSCROLL,0,HIDC_EVALUE
    DEFPUSHBUTTON   "OK",IDOK,4,52,34,14
    PUSHBUTTON      "Cancel",IDCANCEL,230,52,34,14
END

IDD_EDITREDIR DIALOGEX 0, 0, 260, 143
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit Job Redirection"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "File descr",IDC_STATIC,4,10,40,8
    EDITTEXT        IDC_FD,44,8,23,12,ES_NUMBER,0,HIDC_FD
    CONTROL         "Spin1",IDC_SCR_FD,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,66,8,7,14,0,HIDC_SCR_FD
    LTEXT           "(",IDC_STATIC,72,10,8,8
    EDITTEXT        IDC_STDFILE,80,8,40,12,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_STDFILE
    LTEXT           ")",IDC_STATIC,124,10,8,8
    LTEXT           "Connection",IDC_STATIC,4,32,36,8
    CONTROL         "File",IDC_CFILE,"Button",BS_AUTORADIOBUTTON | WS_GROUP | 
                    WS_TABSTOP,48,32,35,10,0,HIDC_CFILE
    CONTROL         "Pipe out to",IDC_PIPETO,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,48,48,44,10,0,HIDC_PIPETO
    CONTROL         "Pipe in from",IDC_PIPEFROM,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,48,64,48,10,0,HIDC_PIPEFROM
    CONTROL         "Close",IDC_CLOSEFILE,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,48,80,35,10,0,HIDC_CLOSEFILE
    CONTROL         "Dup f.d.",IDC_DUPFROM,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,48,96,35,10,0,HIDC_DUPFROM
    CONTROL         "Read",IDC_FREAD,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    104,32,35,10,0,HIDC_FREAD
    CONTROL         "Write",IDC_FWRITE,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    140,32,35,10,0,HIDC_FWRITE
    CONTROL         "Append",IDC_FAPPEND,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,176,32,35,10,0,HIDC_FAPPEND
    EDITTEXT        IDC_FILENAME,104,47,148,12,ES_AUTOHSCROLL,0,
                    HIDC_FILENAME
    EDITTEXT        IDC_FD2,104,96,23,12,ES_NUMBER,0,HIDC_FD2
    CONTROL         "Spin2",IDC_SCR_FD2,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,126,97,7,14,0,HIDC_SCR_FD2
    LTEXT           "(",IDC_BRAC,132,98,8,8
    EDITTEXT        IDC_STDFILE2,140,96,40,12,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_STDFILE2
    LTEXT           ")",IDC_KET,184,98,8,8
    DEFPUSHBUTTON   "OK",IDOK,4,120,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,202,120,50,14
END

IDD_ENVLIST DIALOGEX 0, 0, 335, 186
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job environment variables"
FONT 8, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_ENVLIST,4,12,269,124,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_ENVLIST
    PUSHBUTTON      "New",IDC_NEWENV,284,12,45,17,0,0,HIDC_NEWENV
    PUSHBUTTON      "Edit",IDC_EDITENV,284,65,45,17,0,0,HIDC_EDITENV
    PUSHBUTTON      "Delete",IDC_DELENV,284,118,45,17,0,0,HIDC_DELENV
    DEFPUSHBUTTON   "OK",IDOK,4,156,45,17
    PUSHBUTTON      "Cancel",IDCANCEL,284,156,45,17
END

IDD_JASS DIALOGEX 0, 0, 236, 143
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job Assignments"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_ASSLIST,8,8,176,84,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_ASSLIST
    PUSHBUTTON      "New",IDC_NEWASS,192,8,36,17,0,0,HIDC_NEWASS
    PUSHBUTTON      "Edit",IDC_EDITASS,192,41,36,17,0,0,HIDC_EDITASS
    PUSHBUTTON      "Delete",IDC_ASSDEL,192,74,36,17,0,0,HIDC_ASSDEL
    DEFPUSHBUTTON   "OK",IDOK,8,108,46,17
    PUSHBUTTON      "Cancel",IDCANCEL,182,108,46,17
END

IDD_JCOND DIALOGEX 0, 0, 224, 111
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job conditions"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_CONDLIST,4,8,182,68,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_CONDLIST
    PUSHBUTTON      "New",IDC_NEWCOND,192,8,28,14,0,0,HIDC_NEWCOND
    PUSHBUTTON      "Edit",IDC_EDITCOND,192,35,28,14,0,0,HIDC_EDITCOND
    PUSHBUTTON      "Delete",IDC_CONDDEL,192,62,28,14,0,0,HIDC_CONDDEL
    DEFPUSHBUTTON   "OK",IDOK,8,88,36,14
    PUSHBUTTON      "Cancel",IDCANCEL,184,88,36,14
END

IDD_JOBMODE DIALOGEX 0, 0, 232, 160
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job permissions / user / group"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "User",IDC_STATIC,84,8,16,8
    LTEXT           "Group",IDC_STATIC,112,8,20,8
    LTEXT           "Others",IDC_STATIC,136,8,24,8
    CONTROL         "Read",IDC_JUREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,8,20,88,10,0,HIDC_JUREAD
    CONTROL         "Write",IDC_JUWRITE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,32,88,10,0,HIDC_JUWRITE
    CONTROL         "Reveal",IDC_JUREVEAL,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,44,88,10,0,HIDC_JUREVEAL
    CONTROL         "Display modes",IDC_JUDISPMODE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,56,88,10,0,HIDC_JUDISPMODE
    CONTROL         "Set modes",IDC_JUSETMODE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,68,88,10,0,HIDC_JUSETMODE
    CONTROL         "Assume ownership",IDC_JUASSOWN,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,80,88,10,0,HIDC_JUASSOWN
    CONTROL         "Assume group ownership",IDC_JUASSGOWN,"Button",
                    BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,8,92,88,10,0,
                    HIDC_JUASSGOWN
    CONTROL         "Give away ownership",IDC_JUGOWN,"Button",
                    BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,8,104,88,10,0,
                    HIDC_JUGOWN
    CONTROL         "Give away group",IDC_JUGGROUP,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,116,88,10,0,HIDC_JUGGROUP
    CONTROL         "Delete",IDC_JUDELETE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,128,88,10,0,HIDC_JUDELETE
    CONTROL         "Kill",IDC_JUKILL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,8,140,88,10,0,HIDC_JUKILL
    CONTROL         "",IDC_JGREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,20,12,10,0,HIDC_JGREAD
    CONTROL         "",IDC_JGWRITE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,32,12,10,0,HIDC_JGWRITE
    CONTROL         "",IDC_JGREVEAL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,44,12,10,0,HIDC_JGREVEAL
    CONTROL         "",IDC_JGDISPMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,56,12,10,0,HIDC_JGDISPMODE
    CONTROL         "",IDC_JGSETMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,68,12,10,0,HIDC_JGSETMODE
    CONTROL         "",IDC_JGASSOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,80,12,10,0,HIDC_JGASSOWN
    CONTROL         "",IDC_JGASSGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,92,12,10,0,HIDC_JGASSGOWN
    CONTROL         "",IDC_JGGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,104,12,10,0,HIDC_JGGOWN
    CONTROL         "",IDC_JGGGROUP,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,116,12,10,0,HIDC_JGGGROUP
    CONTROL         "",IDC_JGDELETE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,128,12,10,0,HIDC_JGDELETE
    CONTROL         "",IDC_JGKILL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,140,12,10,0,HIDC_JGKILL
    CONTROL         "",IDC_JOREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,20,12,10,0,HIDC_JOREAD
    CONTROL         "",IDC_JOWRITE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,32,12,10,0,HIDC_JOWRITE
    CONTROL         "",IDC_JOREVEAL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,44,12,10,0,HIDC_JOREVEAL
    CONTROL         "",IDC_JODISPMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,56,12,10,0,HIDC_JODISPMODE
    CONTROL         "",IDC_JOSETMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,68,12,10,0,HIDC_JOSETMODE
    CONTROL         "",IDC_JOASSOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,80,12,10,0,HIDC_JOASSOWN
    CONTROL         "",IDC_JOASSGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,92,12,10,0,HIDC_JOASSGOWN
    CONTROL         "",IDC_JOGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,104,12,10,0,HIDC_JOGOWN
    CONTROL         "",IDC_JOGGROUP,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,116,12,10,0,HIDC_JOGGROUP
    CONTROL         "",IDC_JODELETE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,128,12,10,0,HIDC_JODELETE
    CONTROL         "",IDC_JOKILL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,140,12,10,0,HIDC_JOKILL
    COMBOBOX        IDC_USER,168,16,61,56,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_USER
    COMBOBOX        IDC_GROUP,168,44,61,56,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_GROUP
    DEFPUSHBUTTON   "OK",IDOK,190,110,39,14
    PUSHBUTTON      "Cancel",IDCANCEL,190,138,39,14
END

IDD_MAILWRITE DIALOGEX 0, 0, 140, 55
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Mail/Write flags"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    CONTROL         "Mail completion",IDC_MAIL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,8,8,56,9,0,HIDC_MAIL
    CONTROL         "Write completion",IDC_WRITE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,8,28,68,10,0,HIDC_WRITE
    DEFPUSHBUTTON   "OK",IDOK,98,6,33,11
    PUSHBUTTON      "Cancel",IDCANCEL,98,28,33,11
END

IDD_PROCPAR DIALOGEX 0, 0, 248, 171
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Process parameters"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Directory",IDC_STATIC,8,16,30,8
    EDITTEXT        IDC_DIRECTORY,52,13,164,13,ES_AUTOHSCROLL,0,
                    HIDC_DIRECTORY
    LTEXT           "Umask - turn OFF",IDC_STATIC,8,44,56,8
    LTEXT           "User",IDC_STATIC,72,32,20,8
    CONTROL         "R",IDC_UR,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,72,44,16,10,0,HIDC_UR
    CONTROL         "W",IDC_UW,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,72,56,16,10,0,HIDC_UW
    CONTROL         "X",IDC_UX,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,72,68,16,10,0,HIDC_UX
    LTEXT           "Group",IDC_STATIC,104,32,20,8
    CONTROL         "R",IDC_GR,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,104,44,16,10,0,HIDC_GR
    CONTROL         "W",IDC_GW,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,104,56,16,10,0,HIDC_GW
    CONTROL         "X",IDC_GX,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,104,68,16,10,0,HIDC_GX
    LTEXT           "Others",IDC_STATIC,132,32,20,8
    CONTROL         "R",IDC_OR,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,132,44,16,10,0,HIDC_OR
    CONTROL         "W",IDC_OW,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,132,56,16,10,0,HIDC_OW
    CONTROL         "X",IDC_OX,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,132,68,16,10,0,HIDC_OX
    LTEXT           "Ulimit",IDC_STATIC,172,32,30,8
    EDITTEXT        IDC_ULIMIT,155,52,39,10,0,0,HIDC_ULIMIT
    CONTROL         "Spin1",IDC_SCR_ULIMIT,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,199,51,8,12,0,
                    HIDC_SCR_ULIMIT
    LTEXT           "Normal exit",IDC_STATIC,8,86,36,8
    EDITTEXT        IDC_NEXITL,56,85,22,11,ES_READONLY | ES_NUMBER,0,
                    HIDC_NEXITL
    CONTROL         "Spin2",IDC_SCR_NEXITL,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,76,84,7,12,0,HIDC_SCR_NEXITL
    LTEXT           "to",IDC_STATIC,87,86,12,8
    EDITTEXT        IDC_NEXITU,102,85,22,10,ES_READONLY | ES_NUMBER,0,
                    HIDC_NEXITU
    CONTROL         "Spin3",IDC_SCR_NEXITU,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,121,84,7,12,0,HIDC_SCR_NEXITU
    LTEXT           "Error exit",IDC_STATIC,8,106,36,8
    EDITTEXT        IDC_EEXITL,56,105,22,10,ES_READONLY | ES_NUMBER,0,
                    HIDC_EEXITL
    CONTROL         "Spin4",IDC_SCR_EEXITL,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,77,104,7,12,0,HIDC_SCR_EEXITL
    LTEXT           "to",IDC_STATIC,87,106,12,8
    EDITTEXT        IDC_EEXITU,102,105,22,10,ES_READONLY | ES_NUMBER,0,
                    HIDC_EEXITU
    CONTROL         "Spin5",IDC_SCR_EEXITU,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,124,104,7,12,0,HIDC_SCR_EEXITU
    GROUPBOX        "After error",IDC_STATIC,138,80,105,40
    CONTROL         "Advance time",IDC_ADVTERR,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,144,92,56,10,0,HIDC_ADVTERR
    CONTROL         "Do not advance time",IDC_NADVTERR,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,144,104,76,10,0,
                    HIDC_NADVTERR
    CONTROL         "Remote executable",IDC_REMRUNNABLE,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,72,128,84,10,0,
                    HIDC_REMRUNNABLE
    DEFPUSHBUTTON   "OK",IDOK,16,144,36,14
    PUSHBUTTON      "Cancel",IDCANCEL,190,144,36,14
END

IDD_REDIRLIST DIALOGEX 0, 0, 272, 159
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job redirections"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_REDIRLIST,3,10,209,101,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_REDIRLIST
    DEFPUSHBUTTON   "New",IDC_NEWREDIR,221,10,35,14,0,0,HIDC_NEWREDIR
    DEFPUSHBUTTON   "Edit",IDC_EDITREDIR,221,53,35,14,0,0,HIDC_EDITREDIR
    DEFPUSHBUTTON   "Delete",IDC_DELREDIR,221,96,35,14,0,0,HIDC_DELREDIR
    DEFPUSHBUTTON   "OK",IDOK,3,127,35,14
    PUSHBUTTON      "Cancel",IDCANCEL,221,127,35,14
END

IDD_TIMELIMS DIALOGEX 0, 0, 212, 135
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job time limits"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Delete job after (hours)",IDC_STATIC,8,12,76,7
    EDITTEXT        IDC_DELTIME,96,9,50,12,ES_READONLY,0,HIDC_DELTIME
    CONTROL         "Spin1",IDC_SCR_DELTIME,"msctls_updown32",
                    UDS_SETBUDDYINT | UDS_ALIGNRIGHT | UDS_AUTOBUDDY | 
                    UDS_ARROWKEYS | UDS_NOTHOUSANDS,147,7,10,14,0,
                    HIDC_SCR_DELTIME
    LTEXT           "Maximum run time",IDC_STATIC,8,32,72,8
    EDITTEXT        IDC_HOUR,96,30,21,12,ES_READONLY | ES_NUMBER,0,HIDC_HOUR
    CONTROL         "Spin2",IDC_SCR_HOUR,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,108,29,10,14,0,
                    HIDC_SCR_HOUR
    LTEXT           ":",IDC_COLON,118,33,2,7
    EDITTEXT        IDC_MIN,121,30,21,12,ES_READONLY | ES_NUMBER,0,HIDC_MIN
    CONTROL         "Spin3",IDC_SCR_MIN,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,133,29,10,14,0,
                    HIDC_SCR_MIN
    LTEXT           ":",IDC_COLON2,144,32,2,7
    EDITTEXT        IDC_SEC,148,30,21,12,ES_READONLY | ES_NUMBER,0,HIDC_SEC
    CONTROL         "Spin4",IDC_SCR_SEC,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,162,29,10,14,0,
                    HIDC_SCR_SEC
    PUSHBUTTON      "OFF",IDC_RTOFF,176,29,28,14,0,0,HIDC_RTOFF
    GROUPBOX        "Kill With",IDC_STATIC,28,48,133,53
    CONTROL         "Sigterm",IDC_KW_TERM,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,33,61,35,10,0,HIDC_KW_TERM
    CONTROL         "Sigkill",IDC_KW_KILL,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,33,73,35,10,0,HIDC_KW_KILL
    CONTROL         "Sighup",IDC_KW_HUP,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,33,85,35,10,0,HIDC_KW_HUP
    CONTROL         "Sigint",IDC_KW_INT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,77,61,35,10,0,HIDC_KW_INT
    CONTROL         "Sigquit",IDC_KW_QUIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,77,73,35,10,0,HIDC_KW_QUIT
    CONTROL         "Sigalrm",IDC_KW_ARLM,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,77,85,35,10,0,HIDC_KW_ARLM
    CONTROL         "Sigbus",IDC_KW_BUS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,121,61,35,10,0,HIDC_KW_BUS
    CONTROL         "Sigsegv",IDC_KW_SEGV,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,121,73,35,10,0,HIDC_KW_SEGV
    LTEXT           "Allow to clean up for",IDC_STATIC,8,111,68,8
    EDITTEXT        IDC_MIN2,78,109,23,12,ES_READONLY,0,HIDC_MIN2
    CONTROL         "Spin5",IDC_SCR_MIN2,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,104,108,10,14,0,
                    HIDC_SCR_MIN2
    LTEXT           ":",IDC_COLON3,109,110,2,7
    EDITTEXT        IDC_SEC2,115,109,23,12,ES_READONLY,0,HIDC_SEC2
    CONTROL         "Spin6",IDC_SCR_SEC2,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,140,105,7,14,0,
                    HIDC_SCR_SEC2
    DEFPUSHBUTTON   "OK",IDOK,168,68,36,14,0,0,HIDOK
    PUSHBUTTON      "Cancel",IDCANCEL,168,107,36,14
END

IDD_TITLEPRIO DIALOGEX 6, 18, 171, 135
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Title Command Int Priority Load level"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Title",IDC_STATIC,8,12,29,8
    EDITTEXT        IDC_TITLE,72,8,72,12,ES_AUTOHSCROLL,0,HIDC_TITLE
    LTEXT           "Command Interp",IDC_STATIC,8,32,56,8
    COMBOBOX        IDC_CMDINTERP,72,28,72,36,CBS_DROPDOWNLIST | 
                    CBS_AUTOHSCROLL | CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,
                    HIDC_CMDINTERP
    LTEXT           "Priority",IDC_STATIC,8,56,26,8
    EDITTEXT        IDC_PRIORITY,72,52,30,12,ES_NUMBER,0,HIDC_PRIORITY
    CONTROL         "Spin1",IDC_SCR_PRIORITY,"msctls_updown32",
                    UDS_SETBUDDYINT | UDS_ALIGNRIGHT | UDS_AUTOBUDDY | 
                    UDS_ARROWKEYS | UDS_NOTHOUSANDS,110,51,10,14,0,
                    HIDC_SCR_PRIORITY
    LTEXT           "Load level",IDC_STATIC,8,84,42,8
    EDITTEXT        IDC_LOADLEV,72,80,30,12,ES_NUMBER,0,HIDC_LOADLEV
    CONTROL         "Spin2",IDC_SCR_LOADLEV,"msctls_updown32",
                    UDS_SETBUDDYINT | UDS_ALIGNRIGHT | UDS_AUTOBUDDY | 
                    UDS_ARROWKEYS | UDS_NOTHOUSANDS,110,80,10,14,0,
                    HIDC_SCR_LOADLEV
    DEFPUSHBUTTON   "OK",IDOK,12,108,40,14
    PUSHBUTTON      "Cancel",IDCANCEL,120,108,40,14
END

IDD_USERPERM DIALOGEX 0, 0, 184, 163
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "User Permissions"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "User:",IDC_STATIC,12,8,30,8
    EDITTEXT        IDC_USER,56,5,60,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    0x807b00f7
    LTEXT           "Group:",IDC_STATIC,12,31,30,8
    EDITTEXT        IDC_GROUP,56,28,60,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    0x807b00f8
    CONTROL         "Read admin",IDC_RADMIN,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,44,68,10,0,HIDC_RADMIN
    CONTROL         "Write admin",IDC_WADMIN,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,56,68,10,0,HIDC_WADMIN
    CONTROL         "Create entry",IDC_CREATE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,68,68,10,0,HIDC_CREATE
    CONTROL         "Special Create",IDC_SPCREATE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,80,68,10,0,HIDC_SPCREATE
    CONTROL         "Stop Scheduler",IDC_SSTOP,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,92,68,10,0,HIDC_SSTOP
    CONTROL         "Override def perms",IDC_UMASK,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,104,68,10,0,HIDC_UMASK
    CONTROL         "OR user/group",IDC_ORUG,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,116,68,10,0,HIDC_ORUG
    CONTROL         "OR user/other",IDC_ORUO,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,128,68,10,0,HIDC_ORUO
    CONTROL         "OR group/other",IDC_ORGO,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,140,68,10,0,HIDC_ORGO
    LTEXT           "Max LL",IDC_STATIC,89,50,30,8
    EDITTEXT        IDC_MAXLL,131,48,40,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_MAXLL
    LTEXT           "Tot LL",IDC_STATIC,89,70,20,8
    EDITTEXT        IDC_TOTLL,131,68,40,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_TOTLL
    LTEXT           "Spec LL",IDC_STATIC,89,90,30,8
    EDITTEXT        IDC_SPECLL,131,88,40,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_SPECLL
    DEFPUSHBUTTON   "OK",IDOK,125,110,46,17
    PUSHBUTTON      "Cancel",IDCANCEL,125,136,46,17
END

IDD_LOGINHOST DIALOGEX 0, 0, 186, 131
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Please log in to Unix Host...."
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Login to Unix Host",IDC_STATIC,13,15,55,8
    EDITTEXT        IDC_UNIXHOST,90,13,67,12,ES_AUTOHSCROLL | ES_READONLY | 
                    NOT WS_BORDER | NOT WS_TABSTOP
    LTEXT           "Client Host Name",IDC_STATIC,13,37,53,8
    EDITTEXT        IDC_CLIENTHOST,90,35,67,12,ES_AUTOHSCROLL | ES_READONLY | 
                    NOT WS_BORDER | NOT WS_TABSTOP
    LTEXT           "User Name",IDC_STATIC,13,59,35,8
    EDITTEXT        IDC_USERNAME,64,56,94,14,ES_AUTOHSCROLL,0,HIDC_USERNAME
    LTEXT           "Password",IDC_STATIC,13,81,31,8
    EDITTEXT        IDC_PASSWD,64,78,94,14,ES_PASSWORD | ES_AUTOHSCROLL,0,
                    HIDC_PASSWD
    DEFPUSHBUTTON   "OK",IDOK,7,110,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,129,110,50,14
END


/////////////////////////////////////////////////////////////////////////////
//
// Toolbar
//

IDR_MAINFRAME TOOLBAR DISCARDABLE  16, 15
BEGIN
    BUTTON      ID_FILE_NEW
    BUTTON      ID_FILE_OPEN
    BUTTON      ID_FILE_SAVE
    SEPARATOR
    BUTTON      ID_JOBS_EDITJOB
    BUTTON      ID_ACTION_SUBMITJOB
    SEPARATOR
    BUTTON      ID_ACTION_TITLEPRILOADLEV
    BUTTON      ID_JOBS_TIME
    BUTTON      ID_CONDITIONS_JOBCONDITIONS
    BUTTON      ID_CONDITIONS_JOBASSIGNMENTS
    SEPARATOR
    BUTTON      ID_HELP_INDEX
    BUTTON      ID_CONTEXT_HELP
END


/////////////////////////////////////////////////////////////////////////////
//
// DESIGNINFO
//

#ifdef APSTUDIO_INVOKED
GUIDELINES DESIGNINFO DISCARDABLE 
BEGIN
    IDD_LOGINHOST, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 179
        TOPMARGIN, 7
        BOTTOMMARGIN, 124
    END
END
#endif    // APSTUDIO_INVOKED


/////////////////////////////////////////////////////////////////////////////
//
// String Table
//

STRINGTABLE PRELOAD DISCARDABLE 
BEGIN
    IDR_MAINFRAME           "Submit Xi-Batch Jobs\nbtchjob\nXibatch\nXi-Batch files (*.xbc)\n.xbc\nBtrw.Document\nBtrw Document"
END

STRINGTABLE PRELOAD DISCARDABLE 
BEGIN
    AFX_IDS_APP_TITLE       "Btrw Windows Application"
    AFX_IDS_IDLEMESSAGE     "For Help, press F1"
    AFX_IDS_HELPMODEMESSAGE "Select an object on which to get Help"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_INDICATOR_EXT        "EXT"
    ID_INDICATOR_CAPS       "CAP"
    ID_INDICATOR_NUM        "NUM"
    ID_INDICATOR_SCRL       "SCRL"
    ID_INDICATOR_OVR        "OVR"
    ID_INDICATOR_REC        "REC"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_FILE_NEW             "Create a new document\nNew job doc"
    ID_FILE_OPEN            "Open an existing document\nOpen existing job doc"
    ID_FILE_CLOSE           "Close the active document"
    ID_FILE_SAVE            "Save the active document\nSave job doc"
    ID_FILE_SAVE_AS         "Save the active document with a new name"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_APP_ABOUT            "Display program information, version number and copyright"
    ID_APP_EXIT             "Quit the application; prompts to save documents"
    ID_HELP_INDEX           "List Help topics\nHelp Topics"
    ID_HELP_USING           "Display instructions about how to use help"
    ID_CONTEXT_HELP         "Display help for clicked on buttons, menus and windows\nContext help"
    ID_HELP                 "Display help for current task or command"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_FILE_MRU_FILE1       "Open this document"
    ID_FILE_MRU_FILE2       "Open this document"
    ID_FILE_MRU_FILE3       "Open this document"
    ID_FILE_MRU_FILE4       "Open this document"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_NEXT_PANE            "Switch to the next window pane"
    ID_PREV_PANE            "Switch back to the previous window pane"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_EDIT_CLEAR           "Erase the selection"
    ID_EDIT_CLEAR_ALL       "Erase everything"
    ID_EDIT_COPY            "Copy the selection and put it on the Clipboard"
    ID_EDIT_CUT             "Cut the selection and put it on the Clipboard"
    ID_EDIT_FIND            "Find the specified text"
    ID_EDIT_PASTE           "Insert Clipboard contents"
    ID_EDIT_REPEAT          "Repeat the last action"
    ID_EDIT_REPLACE         "Replace specific text with different text"
    ID_EDIT_SELECT_ALL      "Select the entire document"
    ID_EDIT_UNDO            "Undo the last action"
    ID_EDIT_REDO            "Redo the previously undone action"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_VIEW_TOOLBAR         "Show or hide the toolbar"
    ID_VIEW_STATUS_BAR      "Show or hide the status bar"
END

STRINGTABLE DISCARDABLE 
BEGIN
    AFX_IDS_SCSIZE          "Change the window size"
    AFX_IDS_SCMOVE          "Change the window position"
    AFX_IDS_SCMINIMIZE      "Reduce the window to an icon"
    AFX_IDS_SCMAXIMIZE      "Enlarge the window to full size"
    AFX_IDS_SCNEXTWINDOW    "Switch to the next document window"
    AFX_IDS_SCPREVWINDOW    "Switch to the previous document window"
    AFX_IDS_SCCLOSE         "Close the active window and prompts to save the documents"
END

STRINGTABLE DISCARDABLE 
BEGIN
    AFX_IDS_SCRESTORE       "Restore the window to normal size"
    AFX_IDS_SCTASKLIST      "Activate Task List"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_ACTION_DELETEJOB     "Delete the job (prompt if options set)"
    ID_ACTION_PERMISSIONS   "Set the default permissions and ownership"
    ID_ACTION_TITLEPRILOADLEV 
                            "Set default title, priority and loadlevel \nTitle pri loadlev"
    ID_ACTION_SETRUNNABLE   "Set job runnable"
    ID_ACTION_SETCANCELLED  "Set job cancelled"
    ID_JOBS_TIME            "Set job time and repeat options\nSet time"
    ID_JOBS_PROCPARAM       "Select directory, umask, ulimit, exit code options"
    ID_JOBS_MAIL            "Set default mail / write options"
    ID_JOBS_ARGUMENTS       "Set job arguments"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_JOBS_ENVIRONMENT     "Set environment variables for job"
    ID_JOBS_REDIRECTIONS    "Set I/O redirection parameters for job"
    ID_CONDITIONS_JOBCONDITIONS "Set job dependency conditions\nConditions"
    ID_CONDITIONS_JOBASSIGNMENTS 
                            "Set job assignments at start/end of job\nAssignments"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_DEFAULTS_ARGUMENTS   "Set default job arguments."
    ID_DEFAULTS_REDIRECTIONS "Set default redirections"
    ID_DEFAULTS_CONDITIONS  "Set default conditions"
    ID_DEFAULTS_ASSIGNMENTS "Set default assignments"
    ID_DEFAULTS_NEWCONDITIONS "Default parameters for new conditions."
    ID_DEFAULTS_NEWASSIGNMENTS "Default parameters for new assignments"
    ID_FILE_SAVEDEFAULTS    "Save defaults to file."
    ID_DEFAULTS_SETRUNNABLE "Set to run when ready"
    ID_DEFAULTS_SETCANCELLED "Set to cancelled state"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_FILE_PROGRAMOPTIONS  "Set program options"
    ID_JOBS_EDITJOB         "Edit the script for the job\nEdit job script"
    ID_ACTION_SUBMITJOB     "Submit job to host\nSubmit job"
    ID_ACTION_COPYJOBFILE   "Name a job file for a new job, or copy job file for existing job."
    ID_ENVIRONMENT_ENVIRONMENTDEFAULT 
                            "Copy default environment table from host."
    ID_ENVIRONMENT_CLEARENVIRONMENT "Clear out environment table"
    ID_ENVIRONMENT_SQUEEZEENVIRONMENT 
                            "Squeeze out environment items the same as the default."
    ID_JOBS_TIMELIMITS      "Set default time and run times"
    ID_FILE_USERPERMISSIONS "Display user permissions"
    ID_ACTION_SETDONE       "Set job to be in ""done"" state."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_RETAIN              "Retain"
    IDS_MINUTES             "Mins"
    IDS_HOURS               "Hours"
    IDS_DAYS                "Days"
    IDS_WEEKS               "Weeks"
    IDS_MONTHSB             "MonthsB"
    IDS_MONTHSE             "MonthsE"
    IDS_YEARS               "Years"
    IDS_JOBFNAME            "Job file"
    IDS_QUEUENAME           "Queue"
    IDS_HEADER              "Title"
    IDS_PRINAME             "Priority"
    IDS_CINAME              "Command Interpreter"
    IDS_LOADLNAME           "Load Level"
    IDS_RUNSTATE            "Set to run when ready"
    IDS_CANCSTATE           "Set to cancelled state"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_SUNDAY              "Sunday"
    IDS_MONDAY              "Monday"
    IDS_TUESDAY             "Tuesday"
    IDS_WEDNESDAY           "Wednesday"
    IDS_THURSDAY            "Thursday"
    IDS_FRIDAY              "Friday"
    IDS_SATURDAY            "Saturday"
    IDS_SUN                 "Sun"
    IDS_MON                 "Mon"
    IDS_TUE                 "Tue"
    IDS_WED                 "Wed"
    IDS_THUR                "Thur"
    IDS_FRI                 "Fri"
    IDS_SAT                 "Sat"
    IDS_HDAY                "Hol"
    IDS_DELETE              "Delete"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_JANUARY             "January"
    IDS_FEBRUARY            "February"
    IDS_MARCH               "March"
    IDS_APRIL               "April"
    IDS_MAY                 "May"
    IDS_JUNE                "June"
    IDS_JULY                "July"
    IDS_AUGUST              "August"
    IDS_SEPTEMBER           "September"
    IDS_OCTOBER             "October"
    IDS_NOVEMBER            "November"
    IDS_DECEMBER            "December"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_CANTOPENCMDFILE     "Cannot open command file."
    IDP_NO_HOSTFILE         "There is no hosts file (typically C:\\XIBATCH\\HOSTS). This file should be set up with ""btrsetw"" first."
    IDP_HF_INVALIDHOST      "Unknown or invalid host name in hosts file.\nPlease rerun ""btrsetw""."
    IDP_HF_BADTIMEOUT       "Invalid timeout entry in hosts file.\nPlease re-run ""btrsetw"" and retry."
    IDP_HF_NOALIAS          "Your hosts file specifies a host as an internet address (e.g. 192.10.2.3), but you have given no alias.\nPlease re-run ""sprsetw"" to fix."
    IDP_CANTGETPARAMS       "Cannot get user parameters from host."
    IDP_NO_SERVER           "No server is specified in hosts file. Please set one up (using BTRSETW)."
    IDP_GBTU_NOBIND         "Unable to bind UDP socket to access user details. Please reboot machine."
    IDP_GBTU_NOSEND         "Send failure on UDP socket for accessing user details from server. Please reboot this machine."
    IDP_GBTU_NORECV         "Receive failure obtaining user details from Unix host. Is ""xbnetserv"" running?"
    IDP_GBTU_NVALID         "Invalid user details returned from Unix Server. Is the ""/etc/Xibatch-hosts"" file set up correctly on the server? This machine should be set up as a DOS client and the appropriate user name included."
    IDP_GBTU_NOSOCK         "Unable to create socket entry for accessing user details - aborting."
    IDP_NOCILIST            "Sorry, cannot get ""command interpreter"" list from server."
    IDP_NOTJOBFORMAT        "The batch file does not appear to be in job format (i.e. a ""btr"" command). Please select another file."
    IDP_NOTALLDAYS          "You cannot set every day of the week to avoid!"
    IDP_TOOMANYCONDS        "Too many conditions in job."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_NOCVARSEL           "No condition variable selected to edit."
    IDP_NOCVALUE            "No value in condition."
    IDP_TOOMANYASSES        "Too many assignments in job."
    IDP_NOAFLAGSSET         "No assignment flags are set."
    IDP_NOAVARSEL           "No assignment variable selected."
    IDP_NOAVALUE            "No assignment value provided."
    IDP_NORMBADRANGE        "Bad range given for normal exit codes."
    IDP_ERRBADRANGE         "Bad range given for error exit codes."
    IDP_NOFILENAME          "No file name given in redirection."
    IDP_JLTMINMODE          "The proposed new modes are less than the minimum to enable anyone to do anything."
    IDP_UNDEFSCHEDERR       "Undefined scheduler error - sorry."
    IDP_SCHERR_VNEXIST      "Non-existent variable supplied in job. (Reported by scheduler)."
    IDP_SCHERR_JNOPERM      "Scheduler reports error - no job permission."
    IDP_SCHERR_VNOPERM      "No variable permission, your job is attempting to access a variable beyond the permissions given to the variable."
    IDP_SCHERR_NOPRIV       "No privilege for operation. Possibly you do not have the relevant create permission."
    IDP_SCHERR_SYSVAR       "Your job is attempting to affect a system variable in an improper way."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_SCHERR_SYSVTYPE     "Wrong type assignment to system variable."
    IDP_SCHERR_FULLUP       "Job capacity full. The scheduler cannot accept any more jobs."
    IDP_CWBATFILE           "Trouble writing batch file. This is the .bat file containing the ""btr"" command to re-invoke the job."
    IDP_SCHERR_REMVINLOCJ   "Remote variable in local job."
    IDP_CRMSGFILE           "Cannot read message file for ""btr""."
    IDP_ARGDEFERRS          "Errors in argument definitions in ""btr"" option defaults."
    IDP_SCHERR_LOCVINEXPJ   "Local variable in exported job."
    IDP_SCHERR_MINPRIV      "Privileges too low."
    IDP_SAVEDEFAULTSQ       "Save modified default options before exit?"
    IDP_CANNOTSENDJOB       "Cannot send portions of job"
    IDP_CANNOTRECVJOB       "Cannot receive acknowlegement of portions of job."
    IDP_UNKNOWNCLIENT       "Host reports unknown client. Please put an entry for this machine with appropriate user name in the server file /etc/Xibatch-hosts."
    IDP_NOTCLIENT           "Not a DOS/Windows client on host machine."
    IDP_NOTUSERNAME         "Invalid user name for job."
    IDP_INVALIDCI           "Invalid command interpreter specified."
    IDP_INVALIDCVAR         "Invalid condition variable in job."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_DONESTATE           "Set as ""done""."
    IDS_CONDOP              " "
    IDS_CEQ                 "="
    IDS_CNE                 "!="
    IDS_CLT                 "<"
    IDS_CLE                 "<="
    IDS_CGT                 ">"
    IDS_CGE                 ">="
    IDS_ASSOP               " "
    IDS_AASSIGN             "="
    IDS_AINCR               "+="
    IDS_ADECR               "-="
    IDS_AMULT               "*="
    IDS_ADIV                "/="
    IDS_AMOD                "%="
    IDS_AEXIT               "exit"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_ASIGNAL             "sig"
    IDS_STDIN_NAME          "(stdin)"
    IDS_STDOUT_NAME         "(stdout)"
    IDS_STDERR_NAME         "(stderr)"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_XBENQ_PASSREQ       "You need to supply a password to log in to the server."
    IDP_XBENQ_BADPASSWD     "The supplied password is incorrect."
    IDP_XBENQ_UNKNOWN       "Unknown problem obtaining user data from server."
    IDP_XBENQ_BADCLIENT     "This is an unknown client user or host name. Please check that the /etc/Xibatch-hosts file is correct on the server."
    IDP_XBENQ_UNKNOWNU      "Unable to identify user on server. Please check the windows user name and also the user name(s) in the /etc/Xibatch-hosts file."
    IDP_XBENQ_UNKNOWNG      "Unknown or invalid group. You may be limited to a subset of groups."
    IDP_CONNDIED            "Connection has died to server. Shall I refresh it?"
    IDP_SAVEFIRST           "Save current job before continuing?"
    IDP_DELAREYOUSURE       "Are you sure you want to delete this job?"
    IDP_NOBATFILE           "No batch file name set up - please save first."
    IDP_NOJOBFILE           "No job file created - please create one."
    IDP_SUBMITTEDOK         "Job submitted ok, job number is "
    IDP_UNABLESJ            "Unable to submit job. Is ""xbnetserv"" running ok on host?"
    IDP_TOOMANYSTRINGS      "There are too many strings in the job to pack into the job structure as defined. Please check the contents, in particular, of the environment table as often environments have many spurious entries in."
    IDP_CANTOPENJFILE       "Cannot open job file (at the last fence of creating the job)."
    IDP_OKTOSUBMIT          "Is it ok to submit the job file"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_INVALIDAVAR         "Invalid assignment variable in job."
    IDP_NOMEM_QF            "No memory on host for queue file - sorry"
    IDP_NOCREATEP           "No creation permission - you are not allowed to create new batch jobs, only to edit existing ones."
    IDP_INVALIDPRI          "Invalid priority for job."
    IDP_INVALIDLL           "Invalid load level"
    IDP_INVALIDUSER         "Invalid user name for job submission."
    IDP_FILEFULL            "Unable to create job file on host - the file system is full."
    IDP_MSGQFULL            "The message queues are full on the host system. Cannot create job."
    IDP_INVALIDDATA         "Invalid job data."
    IDP_UNKUSER             "Unknown user for job assignment."
    IDP_UNKGROUP            "Unknown group for job assignment."
    IDP_OTHERERROR          "Job rejected by scheduler. Possibly a remote variable is not available."
    IDP_NOCMODE             "You are not permitted to change permissions from the defaults, sorry, please try again."
    IDP_PENDFULL            "Maximum number of pending jobs reached - please wait."
    IDP_UNKCOMMAND          "Internal error - unknown command."
    IDP_PROTOERR            "Internal error - protocol error"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_SEQERR              "Internal error - sequence error."
    IDP_SJINVALIDARG        "Invalid argument in saved job"
    IDP_SJMISSARG           "Argument in saved job has no parameter"
    IDP_SJINVALIDAVOID      "Invalid day(s) to avoid in saved job"
    IDP_SJTOOMANYCONDS      "Too many condition variables in saved job"
    IDP_SJINVALIDCONDVAR    "Invalid condition in saved job"
    IDP_SJINVALIDCONDOP     "Invalid condition op in saved job"
    IDP_SJINVALIDCONDCONST  "Invalid condition constant in saved job"
    IDP_SJINVALIDSIGNUM     "Invalid signal number in saved job"
    IDP_SJINVALIDFILENUM    "Invalid file number in saved job"
    IDP_SJINVALIDREDIR      "Invalid redirection in saved job"
    IDP_SJUNKNOWNCI         "Unknown redirection in saved job"
    IDP_SJINVALIDMODE       "Invalid mode in saved job"
    IDP_SJINVALIDUMASK      "Invalid umask parameter in saved job"
    IDP_SJINVALIDREP        "Invalid repetition in saved job"
    IDP_SJTOOMANYASSES      "Too many assignments in saved job"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_SJINVALIDASS        "Invalid assignment in saved job"
    IDP_SJINVALIDTIME       "Invalid time parameter in saved job"
    IDP_SJINVALIDDELTIME    "Invalid delete time in saved job"
    IDP_SJINVALIDEXIT       "Invalid exit code range in saved job"
    IDP_SJINVALIDRUNT       "Invalid run time parameter in saved job"
    IDP_SJINVALIDRUNON      "Invalid grace period parameter in saved job"
    IDP_SJNOJOBFILE         "No job file specified in saved command file."
END

#endif    // English (U.K.) resources
/////////////////////////////////////////////////////////////////////////////



#ifndef APSTUDIO_INVOKED
/////////////////////////////////////////////////////////////////////////////
//
// Generated from the TEXTINCLUDE 3 resource.
//
#include "res\btrw.rc2"  // non-App Studio edited resources

#include "afxres.rc"  	// Standard components

/////////////////////////////////////////////////////////////////////////////
#endif    // not APSTUDIO_INVOKED

