/* files.h -- File names

   Copyright 2009 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#define	XI_SOFTWARE	"FSF Inc"
#define	PRODNAME	"GNUbatch"
#define	DEFBASED	"\\GNUBATCH"

#define	BTUNAME		"gnubatch"
#define	MASTER_CONFIG	"config"
#define	HOSTFILE	"hosts"
#define	INT_CONFIG	"config.int"
#define	WININI		"gnubatch.ini"

/*
 *	Port service name for user enquiries
 *	We use the TCP port number to send spr requests and
 *	the UDP one to send/receive user permission
 *	enquiries.
 */

#define	QSERVNAME	"gnubatch-netsrv"
#define	UASERVNAME	"gnubatch-netsrv"

//      Fields in \gnubatch\hosts lines

#define HOSTF_HNAME     0
#define HOSTF_ALIAS     1
#define HOSTF_FLAGS     2
#define HOSTF_TIMEOUT   3
