LIBRARY	xbapi32
DESCRIPTION		"Xi-Batch Release 6 API Library"

EXPORTS
	xb_open
	xb_login
	xb_newgrp
	xb_close
	xb_setmon
	xb_unsetmon
	xb_procmon
	xb_getbtd
	xb_getbtu
	xb_putbtd
	xb_putbtu
	xb_gethenv
	xb_holread
	xb_holupd
	xb_ciadd
	xb_cidel
	xb_ciread
	xb_ciupd
	xb_varadd
	xb_vardel
	xb_varlist
	xb_varread
	xb_varrename
	xb_varupd
	xb_varchcomm
	xb_varchgrp
	xb_varchmod
	xb_varchown
	xb_varfind
	xb_varfindslot
	xb_jobchgrp
	xb_jobchmod
	xb_jobchown
	xb_jobadd
	xb_jobdata
	xb_jobdel
	xb_jobfind
	xb_jobfindslot
	xb_joblist
	xb_jobop
	xb_jobread
	xb_jobupd
	xb_setqueue
	xb_gettitle
	xb_getdirect
	xb_getarg
	xb_unpackenv
	xb_getenv
	xb_getenvlist
	xb_getredir
	xb_puttitle
	xb_putdirect
	xb_putarg
	xb_delarg
	xb_putarglist
	xb_putenv
	xb_delenv
	xb_putelist
	xb_putredir
	xb_delredir
	xb_putredirlist

