//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by Btrw.rc
//
#define IDR_MAINFRAME                   2
#define IDD_ABOUTBOX                    100
#define IDD_ARGLIST                     101
#define IDD_COPYJOBFILE                 102
#define IDD_DEFASS                      103
#define IDD_DEFCONDOPT                  104
#define IDD_EDITARG                     105
#define IDD_EDITASS                     106
#define IDD_EDITCOND                    107
#define IDD_EDITENV                     108
#define IDD_EDITREDIR                   109
#define IDD_ENVLIST                     110
#define IDD_JASS                        111
#define IDD_JCOND                       112
#define IDD_JOBMODE                     113
#define IDD_LOGINHOST                   114
#define IDD_MAILWRITE                   115
#define IDD_NEWJOBFILE                  116
#define IDD_PROCPAR                     117
#define IDD_PROGOPTS                    118
#define IDD_REDIRLIST                   119
#define IDD_TIMELIMS                    120
#define IDD_TIMER                       121
#define IDD_TITLEPRIO                   122
#define IDD_USERPERM                    123
#define IDC_ARGLIST                     150
#define IDC_NEWARG                      151
#define IDC_EDITARG                     152
#define IDC_DELARG                      153
#define IDC_VALUE                       154
#define IDC_SCR_VALUE                   155
#define IDC_ASET                        156
#define IDC_AADD                        157
#define IDC_ASUB                        158
#define IDC_AMULT                       159
#define IDC_ADIV                        160
#define IDC_AMOD                        161
#define IDC_AEXIT                       162
#define IDC_ASIGNAL                     163
#define IDC_ASTART                      164
#define IDC_AREVERSE                    165
#define IDC_ANORMAL                     166
#define IDC_AERROR                      167
#define IDC_AABORT                      168
#define IDC_ACANCEL                     169
#define IDC_ANOTCRIT                    170
#define IDC_ACRIT                       171
#define IDC_CEQ                         172
#define IDC_CNE                         173
#define IDC_CLT                         174
#define IDC_CLE                         175
#define IDC_CGT                         176
#define IDC_CGE                         177
#define IDC_CNOTCRIT                    178
#define IDC_CCRIT                       179
#define IDC_ARGVAL                      180
#define IDC_ASSVAR                      181
#define IDC_CONDVAR                     182
#define IDC_ENAME                       183
#define IDC_EVALUE                      184
#define IDC_FD                          185
#define IDC_SCR_FD                      186
#define IDC_STDFILE                     187
#define IDC_CFILE                       188
#define IDC_PIPETO                      189
#define IDC_PIPEFROM                    190
#define IDC_CLOSEFILE                   191
#define IDC_DUPFROM                     192
#define IDC_FD2                         193
#define IDC_SCR_FD2                     194
#define IDC_STDFILE2                    195
#define IDC_FILENAME                    196
#define IDC_BRAC                        197
#define IDC_KET                         198
#define IDC_FREAD                       199
#define IDC_FWRITE                      200
#define IDC_FAPPEND                     201
#define IDC_ENVLIST                     202
#define IDC_NEWENV                      203
#define IDC_EDITENV                     204
#define IDC_DELENV                      205
#define IDC_ASSLIST                     206
#define IDC_NEWASS                      207
#define IDC_EDITASS                     208
#define IDC_ASSDEL                      209
#define IDC_CONDLIST                    210
#define IDC_NEWCOND                     211
#define IDC_EDITCOND                    212
#define IDC_CONDDEL                     213
#define IDC_JUREAD                      214
#define IDC_JUWRITE                     215
#define IDC_JUREVEAL                    216
#define IDC_JUDISPMODE                  217
#define IDC_JUSETMODE                   218
#define IDC_JUASSOWN                    219
#define IDC_JUASSGOWN                   220
#define IDC_JUGOWN                      221
#define IDC_JUGGROUP                    222
#define IDC_JUDELETE                    223
#define IDC_JUKILL                      224
#define IDC_JGREAD                      225
#define IDC_JGWRITE                     226
#define IDC_JGREVEAL                    227
#define IDC_JGDISPMODE                  228
#define IDC_JGSETMODE                   229
#define IDC_JGASSGOWN                   230
#define IDC_JGASSOWN                    231
#define IDC_JGGOWN                      232
#define IDC_JGGGROUP                    233
#define IDC_JGDELETE                    234
#define IDC_JGKILL                      235
#define IDC_JOREAD                      236
#define IDC_JOWRITE                     237
#define IDC_JOREVEAL                    238
#define IDC_JODISPMODE                  239
#define IDC_JOSETMODE                   240
#define IDC_JOASSGOWN                   241
#define IDC_JOASSOWN                    242
#define IDC_JOGOWN                      243
#define IDC_JOGGROUP                    244
#define IDC_JODELETE                    245
#define IDC_JOKILL                      246
#define IDC_USER                        247
#define IDC_GROUP                       248
#define IDC_UNIXHOST                    249
#define IDC_CLIENTHOST                  250
#define IDC_USERNAME                    251
#define IDC_PASSWD                      252
#define IDC_MAIL                        253
#define IDC_WRITE                       254
#define IDC_DIRECTORY                   255
#define IDC_UR                          256
#define IDC_UW                          257
#define IDC_UX                          258
#define IDC_GR                          259
#define IDC_GW                          260
#define IDC_GX                          261
#define IDC_OR                          262
#define IDC_OW                          263
#define IDC_OX                          264
#define IDC_ULIMIT                      265
#define IDC_SCR_ULIMIT                  266
#define IDC_NEXITL                      267
#define IDC_SCR_NEXITL                  268
#define IDC_NEXITU                      269
#define IDC_SCR_NEXITU                  270
#define IDC_EEXITL                      271
#define IDC_SCR_EEXITL                  272
#define IDC_EEXITU                      273
#define IDC_SCR_EEXITU                  274
#define IDC_ADVTERR                     275
#define IDC_NADVTERR                    276
#define IDC_REMRUNNABLE                 277
#define IDC_JEDITOR                     278
#define IDC_BINMODE                     279
#define IDC_VERBOSE                     280
#define IDC_NONEXPORT                   281
#define IDC_JOBQUEUE                    282
#define IDC_REDIRLIST                   283
#define IDC_NEWREDIR                    284
#define IDC_EDITREDIR                   285
#define IDC_DELREDIR                    286
#define IDC_TIMEISSET                   287
#define IDC_MIN                         288
#define IDC_HOUR                        289
#define IDC_WDAY                        290
#define IDC_MDAY                        291
#define IDC_MON                         292
#define IDC_YEAR                        293
#define IDC_SCR_MIN                     294
#define IDC_SCR_HOUR                    295
#define IDC_SCR_WDAY                    296
#define IDC_SCR_MDAY                    297
#define IDC_SCR_MON                     298
#define IDC_SCR_YEAR                    299
#define IDC_COLON                       300
#define IDC_DELETE                      301
#define IDC_RETAIN                      302
#define IDC_REPMINS                     303
#define IDC_REPHOURS                    304
#define IDC_REPDAYS                     305
#define IDC_REPWEEKS                    306
#define IDC_REPMONTHSB                  307
#define IDC_REPMONTHSE                  308
#define IDC_REPYEARS                    309
#define IDC_MESS_REPEATEVERY            310
#define IDC_REPEAT                      311
#define IDC_SCR_REPEAT                  312
#define IDC_MONDAYNAME                  313
#define IDC_MONTHDAY                    314
#define IDC_SCR_MONTHDAY                315
#define IDC_MESS_AVOIDING               316
#define IDC_AVSUN                       317
#define IDC_AVMON                       318
#define IDC_AVTUE                       319
#define IDC_AVWED                       320
#define IDC_AVTHU                       321
#define IDC_AVFRI                       322
#define IDC_AVSAT                       323
#define IDC_AVHOLIDAY                   324
#define IDC_MESS_NOTPOSS                325
#define IDC_NPSKIP                      326
#define IDC_NPDELCURR                   327
#define IDC_NPDELALL                    328
#define IDC_NPCATCHUP                   329
#define IDC_MESS_COMESTO                330
#define IDC_REPRESULT                   331
#define IDC_DELTIME                     332
#define IDC_SCR_DELTIME                 333
#define IDC_COLON2                      334
#define IDC_SEC                         335
#define IDC_SCR_SEC                     336
#define IDC_RTOFF                       337
#define IDC_KW_TERM                     338
#define IDC_KW_KILL                     339
#define IDC_KW_HUP                      340
#define IDC_KW_INT                      341
#define IDC_KW_QUIT                     342
#define IDC_KW_ARLM                     343
#define IDC_KW_BUS                      344
#define IDC_KW_SEGV                     345
#define IDC_MIN2                        346
#define IDC_SEC2                        347
#define IDC_SCR_MIN2                    348
#define IDC_SCR_SEC2                    349
#define IDC_COLON3                      350
#define IDC_TITLE                       351
#define IDC_CMDINTERP                   352
#define IDC_PRIORITY                    353
#define IDC_SCR_PRIORITY                354
#define IDC_LOADLEV                     355
#define IDC_SCR_LOADLEV                 356
#define IDC_RADMIN                      357
#define IDC_WADMIN                      358
#define IDC_CREATE                      359
#define IDC_SPCREATE                    360
#define IDC_SSTOP                       361
#define IDC_UMASK                       362
#define IDC_ORUG                        363
#define IDC_ORUO                        364
#define IDC_ORGO                        365
#define IDC_MAXLL                       366
#define IDC_TOTLL                       367
#define IDC_SPECLL                      368
#define IDS_JANUARY                     500
#define IDS_FEBRUARY                    501
#define IDS_MARCH                       502
#define IDS_APRIL                       503
#define IDS_MAY                         504
#define IDS_JUNE                        505
#define IDS_JULY                        506
#define IDS_AUGUST                      507
#define IDS_SEPTEMBER                   508
#define IDS_OCTOBER                     509
#define IDS_NOVEMBER                    510
#define IDS_DECEMBER                    511
#define IDS_SUNDAY                      512
#define IDS_MONDAY                      513
#define IDS_TUESDAY                     514
#define IDS_WEDNESDAY                   515
#define IDS_THURSDAY                    516
#define IDS_FRIDAY                      517
#define IDS_SATURDAY                    518
#define IDS_SUN                         519
#define IDS_MON                         520
#define IDS_TUE                         521
#define IDS_WED                         522
#define IDS_THUR                        523
#define IDS_FRI                         524
#define IDS_SAT                         525
#define IDS_HDAY                        526
#define IDS_DELETE                      527
#define IDS_RETAIN                      528
#define IDS_MINUTES                     529
#define IDS_HOURS                       530
#define IDS_DAYS                        531
#define IDS_WEEKS                       532
#define IDS_MONTHSB                     533
#define IDS_MONTHSE                     534
#define IDS_YEARS                       535
#define IDS_JOBFNAME                    536
#define IDS_QUEUENAME                   537
#define IDS_HEADER                      538
#define IDS_PRINAME                     539
#define IDS_CINAME                      540
#define IDS_LOADLNAME                   541
#define IDS_RUNSTATE                    542
#define IDS_CANCSTATE                   543
#define IDS_DONESTATE                   544
#define IDS_CONDOP                      545
#define IDS_CEQ                         546
#define IDS_CNE                         547
#define IDS_CLT                         548
#define IDS_CLE                         549
#define IDS_CGT                         550
#define IDS_CGE                         551
#define IDS_ASSOP                       552
#define IDS_AASSIGN                     553
#define IDS_AINCR                       554
#define IDS_ADECR                       555
#define IDS_AMULT                       556
#define IDS_ADIV                        557
#define IDS_AMOD                        558
#define IDS_AEXIT                       559
#define IDS_ASIGNAL                     560
#define IDS_STDIN_NAME                  561
#define IDS_STDOUT_NAME                 562
#define IDS_STDERR_NAME                 563
#define IDP_XBENQ_PASSREQ               2000
#define IDP_XBENQ_BADPASSWD             2001
#define IDP_XBENQ_UNKNOWN               2002
#define IDP_XBENQ_BADCLIENT             2003
#define IDP_XBENQ_UNKNOWNU              2004
#define IDP_XBENQ_UNKNOWNG              2005
#define IDP_CONNDIED                    2006
#define IDP_SAVEFIRST                   2007
#define IDP_DELAREYOUSURE               2008
#define IDP_NOBATFILE                   2009
#define IDP_NOJOBFILE                   2010
#define IDP_SUBMITTEDOK                 2011
#define IDP_UNABLESJ                    2012
#define IDP_TOOMANYSTRINGS              2013
#define IDP_CANTOPENJFILE               2014
#define IDP_OKTOSUBMIT                  2015
#define IDP_CANTOPENCMDFILE             2016
#define IDP_NO_HOSTFILE                 2017
#define IDP_HF_INVALIDHOST              2018
#define IDP_HF_BADTIMEOUT               2019
#define IDP_HF_NOALIAS                  2020
#define IDP_CANTGETPARAMS               2021
#define IDP_NO_SERVER                   2022
#define IDP_GBTU_NOBIND                 2023
#define IDP_GBTU_NOSEND                 2024
#define IDP_GBTU_NORECV                 2025
#define IDP_GBTU_NVALID                 2026
#define IDP_GBTU_NOSOCK                 2027
#define IDP_NOCILIST                    2028
#define IDP_NOTJOBFORMAT                2029
#define IDP_NOTALLDAYS                  2030
#define IDP_TOOMANYCONDS                2031
#define IDP_NOCVARSEL                   2032
#define IDP_NOCVALUE                    2033
#define IDP_TOOMANYASSES                2034
#define IDP_NOAFLAGSSET                 2035
#define IDP_NOAVARSEL                   2036
#define IDP_NOAVALUE                    2037
#define IDP_NORMBADRANGE                2038
#define IDP_ERRBADRANGE                 2039
#define IDP_NOFILENAME                  2040
#define IDP_JLTMINMODE                  2041
#define IDP_UNDEFSCHEDERR               2042
#define IDP_SCHERR_VNEXIST              2043
#define IDP_SCHERR_JNOPERM              2044
#define IDP_SCHERR_VNOPERM              2045
#define IDP_SCHERR_NOPRIV               2046
#define IDP_SCHERR_SYSVAR               2047
#define IDP_SCHERR_SYSVTYPE             2048
#define IDP_SCHERR_FULLUP               2049
#define IDP_CWBATFILE                   2050
#define IDP_SCHERR_REMVINLOCJ           2051
#define IDP_CRMSGFILE                   2052
#define IDP_ARGDEFERRS                  2053
#define IDP_SCHERR_LOCVINEXPJ           2054
#define IDP_SCHERR_MINPRIV              2055
#define IDP_SAVEDEFAULTSQ               2056
#define IDP_CANNOTSENDJOB               2057
#define IDP_CANNOTRECVJOB               2058
#define IDP_UNKNOWNCLIENT               2059
#define IDP_NOTCLIENT                   2060
#define IDP_NOTUSERNAME                 2061
#define IDP_INVALIDCI                   2062
#define IDP_INVALIDCVAR                 2063
#define IDP_INVALIDAVAR                 2064
#define IDP_NOMEM_QF                    2065
#define IDP_NOCREATEP                   2066
#define IDP_INVALIDPRI                  2067
#define IDP_INVALIDLL                   2068
#define IDP_INVALIDUSER                 2069
#define IDP_FILEFULL                    2070
#define IDP_MSGQFULL                    2071
#define IDP_INVALIDDATA                 2072
#define IDP_UNKUSER                     2073
#define IDP_UNKGROUP                    2074
#define IDP_OTHERERROR                  2075
#define IDP_NOCMODE                     2076
#define IDP_PENDFULL                    2077
#define IDP_UNKCOMMAND                  2078
#define IDP_PROTOERR                    2079
#define IDP_SEQERR                      2080
#define IDP_SJINVALIDARG                2081
#define IDP_SJMISSARG                   2082
#define IDP_SJINVALIDAVOID              2083
#define IDP_SJTOOMANYCONDS              2084
#define IDP_SJINVALIDCONDVAR            2085
#define IDP_SJINVALIDCONDOP             2086
#define IDP_SJINVALIDCONDCONST          2087
#define IDP_SJINVALIDSIGNUM             2088
#define IDP_SJINVALIDFILENUM            2089
#define IDP_SJINVALIDREDIR              2090
#define IDP_SJUNKNOWNCI                 2091
#define IDP_SJINVALIDMODE               2092
#define IDP_SJINVALIDUMASK              2093
#define IDP_SJINVALIDREP                2094
#define IDP_SJTOOMANYASSES              2095
#define IDP_SJINVALIDASS                2096
#define IDP_SJINVALIDTIME               2097
#define IDP_SJINVALIDDELTIME            2098
#define IDP_SJINVALIDEXIT               2099
#define IDP_SJINVALIDRUNT               2100
#define IDP_SJINVALIDRUNON              2101
#define IDP_SJNOJOBFILE                 2102
#define ID_FILE_PROGRAMOPTIONS          32771
#define ID_JOBS_EDITJOB                 32772
#define ID_ACTION_SUBMITJOB             32773
#define ID_ACTION_COPYJOBFILE           32775
#define ID_ENVIRONMENT_ENVIRONMENTDEFAULT 32777
#define ID_ENVIRONMENT_CLEARENVIRONMENT 32778
#define ID_ENVIRONMENT_SQUEEZEENVIRONMENT 32779
#define ID_JOBS_TIMELIMITS              32780
#define ID_FILE_USERPERMISSIONS         32781
#define ID_ACTION_SETDONE               32782
#define ID_DEFAULTS_TIME                32784
#define ID_DEFAULTS_TITLEPRILOADLEV     32785
#define ID_DEFAULTS_PROCPARAM           32786
#define ID_DEFAULTS_TIMELIMITS          32788
#define ID_DEFAULTS_PERMISSIONS         32789
#define ID_DEFAULTS_MAIL                32790
#define ID_DEFAULTS_ARGUMENTS           32791
#define ID_DEFAULTS_REDIRECTIONS        32792
#define ID_DEFAULTS_CONDITIONS          32793
#define ID_DEFAULTS_ASSIGNMENTS         32794
#define ID_DEFAULTS_NEWCONDITIONS       32795
#define ID_DEFAULTS_NEWASSIGNMENTS      32796
#define ID_FILE_SAVEDEFAULTS            32797
#define ID_DEFAULTS_SETRUNNABLE         32798
#define ID_DEFAULTS_SETCANCELLED        32799
#define ID_ACTION_DELETEJOB             32821
#define ID_ACTION_PERMISSIONS           32822
#define ID_ACTION_TITLEPRILOADLEV       32823
#define ID_ACTION_SETRUNNABLE           32824
#define ID_ACTION_SETCANCELLED          32825
#define ID_JOBS_TIME                    32828
#define ID_JOBS_PROCPARAM               32829
#define ID_JOBS_MAIL                    32830
#define ID_JOBS_ARGUMENTS               32831
#define ID_JOBS_ENVIRONMENT             32832
#define ID_JOBS_REDIRECTIONS            32833
#define ID_CONDITIONS_JOBCONDITIONS     32834
#define ID_CONDITIONS_JOBASSIGNMENTS    32835

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        124
#define _APS_NEXT_COMMAND_VALUE         32811
#define _APS_NEXT_CONTROL_VALUE         369
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
