//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by Btrsetw.rc
//
#define IDR_MAINFRAME                   2
#define IDD_ABOUTBOX                    100
#define IDD_DEFASS                      101
#define IDD_DEFCOND                     102
#define IDD_DEFTIMES                    103
#define IDD_HOST                        104
#define IDD_JOBMODE                     105
#define IDD_LOGINHOST                   106
#define IDD_LOGINOUT                    107
#define IDD_NEWGROUP                    108
#define IDD_PORTNUMS                    109
#define IDD_PROCPAR                     110
#define IDD_PROGOPTS                    111
#define IDD_QUEUEDEFS                   112
#define IDD_TIMELIMS                    113
#define IDS_NOTLOGGED                   120
#define IDS_UNKNOWN                     121
#define IDS_PROBE                       122
#define IDS_SERVER                      123
#define IDS_FOO                         124
#define IDC_VALUE                       150
#define IDC_SCR_VALUE                   151
#define IDC_ASET                        152
#define IDC_AADD                        153
#define IDC_ASUB                        154
#define IDC_AMULT                       155
#define IDC_ADIV                        156
#define IDC_AMOD                        157
#define IDC_AEXIT                       158
#define IDC_ASIGNAL                     159
#define IDC_ASTART                      160
#define IDC_AREVERSE                    161
#define IDC_ANORMAL                     162
#define IDC_AERROR                      163
#define IDC_AABORT                      164
#define IDC_ACANCEL                     165
#define IDC_ANOTCRIT                    166
#define IDC_ACRIT                       167
#define IDC_CEQ                         168
#define IDC_CNE                         169
#define IDC_CLT                         170
#define IDC_CLE                         171
#define IDC_CGT                         172
#define IDC_CGE                         173
#define IDC_CNOTCRIT                    174
#define IDC_CCRIT                       175
#define IDC_DELETE                      176
#define IDC_RETAIN                      177
#define IDC_REPMINS                     178
#define IDC_REPHOURS                    179
#define IDC_REPDAYS                     180
#define IDC_REPWEEKS                    181
#define IDC_REPMONTHSB                  182
#define IDC_REPMONTHSE                  183
#define IDC_REPYEARS                    184
#define IDC_MESS_REPEATEVERY            185
#define IDC_REPEAT                      186
#define IDC_SCR_REPEAT                  187
#define IDC_MONDAYNAME                  188
#define IDC_MONTHDAY                    189
#define IDC_SCR_MONTHDAY                190
#define IDC_MESS_AVOIDING               191
#define IDC_AVSUN                       192
#define IDC_AVMON                       193
#define IDC_AVTUE                       194
#define IDC_AVWED                       195
#define IDC_AVTHU                       196
#define IDC_AVFRI                       197
#define IDC_AVSAT                       198
#define IDC_AVHOLIDAY                   199
#define IDC_MESS_NOTPOSS                200
#define IDC_NPSKIP                      201
#define IDC_NPDELCURR                   202
#define IDC_NPDELALL                    203
#define IDC_NPCATCHUP                   204
#define IDC_HOSTNAME                    205
#define IDC_ALIASNAME                   206
#define IDC_TIMEOUT                     207
#define IDC_SCR_TIMEOUT                 208
#define IDC_PROBEFIRST                  209
#define IDC_JUREAD                      210
#define IDC_JUWRITE                     211
#define IDC_JUREVEAL                    212
#define IDC_JUDISPMODE                  213
#define IDC_JUSETMODE                   214
#define IDC_JUASSOWN                    215
#define IDC_JUASSGOWN                   216
#define IDC_JUGOWN                      217
#define IDC_JUGGROUP                    218
#define IDC_JUDELETE                    219
#define IDC_JUKILL                      220
#define IDC_JGREAD                      221
#define IDC_JGWRITE                     222
#define IDC_JGREVEAL                    223
#define IDC_JGDISPMODE                  224
#define IDC_JGSETMODE                   225
#define IDC_JGASSGOWN                   226
#define IDC_JGASSOWN                    227
#define IDC_JGGOWN                      228
#define IDC_JGGGROUP                    229
#define IDC_JGDELETE                    230
#define IDC_JGKILL                      231
#define IDC_JOREAD                      232
#define IDC_JOWRITE                     233
#define IDC_JOREVEAL                    234
#define IDC_JODISPMODE                  235
#define IDC_JOSETMODE                   236
#define IDC_JOASSGOWN                   237
#define IDC_JOASSOWN                    238
#define IDC_JOGOWN                      239
#define IDC_JOGGROUP                    240
#define IDC_JODELETE                    241
#define IDC_JOKILL                      242
#define IDC_USER                        243
#define IDC_GROUP                       244
#define IDC_UNIXHOST                    245
#define IDC_CLIENTHOST                  246
#define IDC_USERNAME                    247
#define IDC_PASSWD                      248
#define IDC_UNIXUSER                    249
#define IDC_WINUSER                     250
#define IDC_LOGIN                       251
#define IDC_LOGOUT                      252
#define IDC_SETDEFAULT                  253
#define IDC_INCALLBY                    254
#define IDC_SCR_INCALLBY                255
#define IDC_APPLYINC                    256
#define IDC_APPLYDEC                    257
#define IDC_CLIENTPORT                  258
#define IDC_SCR_CLIENTPORT              259
#define IDC_PROBEPORT                   260
#define IDC_SCR_PROBEPORT               261
#define IDC_CONNPORT                    262
#define IDC_SCR_CONNPORT                263
#define IDC_VIEWPORT                    264
#define IDC_SCR_VIEWPORT                265
#define IDC_APITCPPORT                  266
#define IDC_SCR_APITCPPORT              267
#define IDC_APIUDPPORT                  268
#define IDC_SCR_APIUDPPORT              269
#define IDC_SAVESETTINGS                270
#define IDC_DIRECTORY                   271
#define IDC_UR                          272
#define IDC_UW                          273
#define IDC_UX                          274
#define IDC_GR                          275
#define IDC_GW                          276
#define IDC_GX                          277
#define IDC_OR                          278
#define IDC_OW                          279
#define IDC_OX                          280
#define IDC_ULIMIT                      281
#define IDC_SCR_ULIMIT                  282
#define IDC_NEXITL                      283
#define IDC_SCR_NEXITL                  284
#define IDC_NEXITU                      285
#define IDC_SCR_NEXITU                  286
#define IDC_EEXITL                      287
#define IDC_SCR_EEXITL                  288
#define IDC_EEXITU                      289
#define IDC_SCR_EEXITU                  290
#define IDC_ADVTERR                     291
#define IDC_NADVTERR                    292
#define IDC_LOCAL                       293
#define IDC_EXPORT                      294
#define IDC_REMRUNNABLE                 295
#define IDC_VERBOSE                     296
#define IDC_BINMODE                     297
#define IDC_TITLE                       298
#define IDC_CMDINTERP                   299
#define IDC_PRIORITY                    300
#define IDC_SCR_PRIORITY                301
#define IDC_LOADLEV                     302
#define IDC_SCR_LOADLEV                 303
#define IDC_DELTIME                     304
#define IDC_SCR_DELTIME                 305
#define IDC_HOUR                        306
#define IDC_SCR_HOUR                    307
#define IDC_COLON                       308
#define IDC_MIN                         309
#define IDC_SCR_MIN                     310
#define IDC_COLON2                      311
#define IDC_SEC                         312
#define IDC_SCR_SEC                     313
#define IDC_RTOFF                       314
#define IDC_KW_TERM                     315
#define IDC_KW_KILL                     316
#define IDC_KW_HUP                      317
#define IDC_KW_INT                      318
#define IDC_KW_QUIT                     319
#define IDC_KW_ARLM                     320
#define IDC_KW_BUS                      321
#define IDC_KW_SEGV                     322
#define IDC_MIN2                        323
#define IDC_SCR_MIN2                    324
#define IDC_COLON3                      325
#define IDC_SEC2                        326
#define IDC_SCR_SEC2                    327
#define IDC_JOBQUEUE                    328
#define IDP_XBENQ_PASSREQ               2000
#define IDP_XBENQ_BADPASSWD             2001
#define IDP_XBENQ_UNKNOWN               2002
#define IDP_XBENQ_BADCLIENT             2003
#define IDP_XBENQ_UNKNOWNU              2004
#define IDP_XBENQ_UNKNOWNG              2005
#define IDP_CONNDIED                    2006
#define IDP_PREVINSTANCE                2007
#define IDP_NOHOSTSYET                  2008
#define IDP_NOTSELECTED                 2009
#define IDP_SUREDEL                     2010
#define IDP_NOHOSTNAME                  2011
#define IDP_NOALIASNAME                 2012
#define IDP_ALIASSAMEASHOST             2013
#define IDP_BADINETADDR                 2014
#define IDP_HIDCLASH                    2015
#define IDP_HIDCLASHMINE                2016
#define IDP_ALIASCLASH                  2017
#define IDP_HOSTCLASH                   2018
#define IDP_UNKNOWNHOSTNAME             2019
#define IDP_MYHOSTNAME                  2020
#define IDP_NOTALIVE                    2021
#define IDP_NO_SERVER                   2022
#define IDP_NO_HOSTFILE                 2023
#define IDP_HF_INVALIDHOST              2024
#define IDP_HF_BADTIMEOUT               2025
#define IDP_HF_NOALIAS                  2026
#define IDP_GBTU_NOBIND                 2027
#define IDP_GBTU_NOSEND                 2028
#define IDP_GBTU_NORECV                 2029
#define IDP_GBTU_NVALID                 2030
#define IDP_GBTU_NOSOCK                 2031
#define IDP_NOCILIST                    2032
#define IDP_NORMBADRANGE                2033
#define IDP_ERRBADRANGE                 2034
#define IDP_JLTMINMODE                  2035
#define IDP_SURERESTORE                 2036
#define IDP_SAVEPROPTS                  2037
#define ID_PROGRAM_SAVE                 32768
#define ID_NETWORK_ADDNEWHOST           32769
#define ID_NETWORK_DELETEHOST           32770
#define ID_NETWORK_CHANGEHOST           32771
#define ID_NETWORK_SETASSERVER          32772
#define ID_OPTIONS_PROGRAMDEFAULTS      32773
#define ID_OPTIONS_RESTOREDEFAULTS      32774
#define ID_OPTIONS_TIMEDEFAULTS         32775
#define ID_OPTIONS_CONDITIONDEFAULTS    32776
#define ID_OPTIONS_ASSIGNMENTDEFAULTS   32777
#define ID_OPTIONS_QUEUEDEFAULTS        32778
#define ID_OPTIONS_PROCESSPARAMETERS    32779
#define ID_OPTIONS_PERMISSIONS          32780
#define ID_OPTIONS_TIMELIMITS           32781
#define ID_PROGRAM_PORTSETTINGS         32782
#define ID_PROGRAM_LOGINORLOGOUT        32796
#define ID_PROGRAM_NEWGROUP             32797

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        114
#define _APS_NEXT_COMMAND_VALUE         32798
#define _APS_NEXT_CONTROL_VALUE         329
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
