// "About Btrw" Dialog Box (IDD_ABOUTBOX == 100)


/*
const DWORD a100HelpIDs[]=
{
	0, 0
};
*/

// "Job Argument List" Dialog Box (IDD_ARGLIST == 101)

#define IDH_101_150	9830501	// Job Argument List: "" (ListBox)
#define IDH_101_151	9896037	// Job Argument List: "New" (Button)
#define IDH_101_152	9961573	// Job Argument List: "Edit" (Button)
#define IDH_101_153	10027109	// Job Argument List: "Delete" (Button)

/*
*/

// "Assignment defaults" Dialog Box (IDD_DEFASS == 103)

#define IDH_103_164	10748007	// Assignment defaults: "On start" (Button)
#define IDH_103_170	11141223	// Assignment defaults: "Ignore" (Button)
#define IDH_103_154	10092647	// Assignment defaults: "" (Edit)
#define IDH_103_156	10223719	// Assignment defaults: "Set" (Button)

/*
*/

// "Condition defaults" Dialog Box (IDD_DEFCONDOPT == 104)

#define IDH_104_172	11272296	// Condition defaults: "=" (Button)
#define IDH_104_154	10092648	// Condition defaults: "" (Edit)
#define IDH_104_178	11665512	// Condition defaults: "Ignore" (Button)

/*
*/

// "Edit Argument" Dialog Box (IDD_EDITARG == 105)

#define IDH_105_180	11796585	// Edit Argument: "" (Edit)

/*
*/

// "Edit Assignment" Dialog Box (IDD_EDITASS == 106)

#define IDH_106_162	10616938	// Edit Assignment: "Exit" (Button)
#define IDH_106_163	10682474	// Edit Assignment: "Sig" (Button)
#define IDH_106_164	10748010	// Edit Assignment: "On start" (Button)
#define IDH_106_165	10813546	// Edit Assignment: "REVERSE on exit" (Button)
#define IDH_106_166	10879082	// Edit Assignment: "Normal exit" (Button)
#define IDH_106_167	10944618	// Edit Assignment: "Error exit" (Button)
#define IDH_106_168	11010154	// Edit Assignment: "Abort" (Button)
#define IDH_106_169	11075690	// Edit Assignment: "Cancel" (Button)
#define IDH_106_170	11141226	// Edit Assignment: "Ignore" (Button)
#define IDH_106_171	11206762	// Edit Assignment: "Hold job" (Button)
#define IDH_106_154	10092650	// Edit Assignment: "" (Edit)
#define IDH_106_156	10223722	// Edit Assignment: "Set" (Button)
#define IDH_106_157	10289258	// Edit Assignment: "+" (Button)
#define IDH_106_181	11862122	// Edit Assignment: "" (ComboBox)
#define IDH_106_158	10354794	// Edit Assignment: "-" (Button)
#define IDH_106_159	10420330	// Edit Assignment: "X" (Button)
#define IDH_106_160	10485866	// Edit Assignment: "/" (Button)
#define IDH_106_161	10551402	// Edit Assignment: "Md" (Button)

/*
*/

// "Edit condition" Dialog Box (IDD_EDITCOND == 107)

#define IDH_107_172	11272299	// Edit condition: "=" (Button)
#define IDH_107_154	10092651	// Edit condition: "" (Edit)
#define IDH_107_178	11665515	// Edit condition: "Ignore" (Button)
#define IDH_107_179	11731051	// Edit condition: "Hold job" (Button)
#define IDH_107_182	11927659	// Edit condition: "" (ComboBox)

/*
*/

// "Edit environment variable" Dialog Box (IDD_EDITENV == 108)

#define IDH_108_183	11993196	// Edit environment variable: "" (Edit)
#define IDH_108_184	12058732	// Edit environment variable: "" (Edit)

/*
*/

// "Edit Job Redirection" Dialog Box (IDD_EDITREDIR == 109)

#define IDH_109_185	12124269	// Edit Job Redirection: "0" (Edit)
#define IDH_109_187	12255341	// Edit Job Redirection: "" (Edit)
#define IDH_109_188	12320877	// Edit Job Redirection: "File" (Button)
#define IDH_109_189	12386413	// Edit Job Redirection: "Pipe out to" (Button)
#define IDH_109_190	12451949	// Edit Job Redirection: "Pipe in from" (Button)
#define IDH_109_191	12517485	// Edit Job Redirection: "Close" (Button)
#define IDH_109_192	12583021	// Edit Job Redirection: "Dup f.d." (Button)
#define IDH_109_193	12648557	// Edit Job Redirection: "0" (Edit)
#define IDH_109_195	12779629	// Edit Job Redirection: "" (Edit)
#define IDH_109_196	12845165	// Edit Job Redirection: "" (Edit)
#define IDH_109_199	13041773	// Edit Job Redirection: "Read" (Button)
#define IDH_109_200	13107309	// Edit Job Redirection: "Write" (Button)
#define IDH_109_201	13172845	// Edit Job Redirection: "Append" (Button)

/*
*/

// "Job environment variables" Dialog Box (IDD_ENVLIST == 110)

#define IDH_110_202	13238382	// Job environment variables: "" (ListBox)
#define IDH_110_203	13303918	// Job environment variables: "New" (Button)
#define IDH_110_204	13369454	// Job environment variables: "Edit" (Button)
#define IDH_110_205	13434990	// Job environment variables: "Delete" (Button)

/*
*/

// "Job Assignments" Dialog Box (IDD_JASS == 111)

#define IDH_111_208	13631599	// Job Assignments: "Edit" (Button)
#define IDH_111_209	13697135	// Job Assignments: "Delete" (Button)
#define IDH_111_206	13500527	// Job Assignments: "" (ListBox)
#define IDH_111_207	13566063	// Job Assignments: "New" (Button)

/*
*/

// "Job conditions" Dialog Box (IDD_JCOND == 112)

#define IDH_112_210	13762672	// Job conditions: "" (ListBox)
#define IDH_112_211	13828208	// Job conditions: "New" (Button)
#define IDH_112_212	13893744	// Job conditions: "Edit" (Button)
#define IDH_112_213	13959280	// Job conditions: "Delete" (Button)

/*
*/

// "Job permissions / user / group" Dialog Box (IDD_JOBMODE == 113)

#define IDH_113_214	14024817	// Job permissions / user / group: "Read" (Button)
#define IDH_113_247	16187505	// Job permissions / user / group: "" (ComboBox)
#define IDH_113_248	16253041	// Job permissions / user / group: "" (ComboBox)

/*
*/

// "Please log in to Unix Host...." Dialog Box (IDD_LOGINHOST == 114)

#define IDH_114_249	16318578	// Please log in to Unix Host....: "" (Edit)
#define IDH_114_250	16384114	// Please log in to Unix Host....: "" (Edit)
#define IDH_114_251	16449650	// Please log in to Unix Host....: "" (Edit)
#define IDH_114_252	16515186	// Please log in to Unix Host....: "" (Edit)

/*
*/

// "Mail/Write flags" Dialog Box (IDD_MAILWRITE == 115)

#define IDH_115_254	16646259	// Mail/Write flags: "Write completion" (Button)
#define IDH_115_253	16580723	// Mail/Write flags: "Mail completion" (Button)

/*
*/

// "Process parameters" Dialog Box (IDD_PROCPAR == 117)

#define IDH_117_277	18153589	// Process parameters: "Remote executable" (Button)
#define IDH_117_255	16711797	// Process parameters: "" (Edit)
#define IDH_117_256	16777333	// Process parameters: "R" (Button)
#define IDH_117_257	16842869	// Process parameters: "W" (Button)
#define IDH_117_258	16908405	// Process parameters: "X" (Button)
#define IDH_117_259	16973941	// Process parameters: "R" (Button)
#define IDH_117_260	17039477	// Process parameters: "W" (Button)
#define IDH_117_261	17105013	// Process parameters: "X" (Button)
#define IDH_117_262	17170549	// Process parameters: "R" (Button)
#define IDH_117_263	17236085	// Process parameters: "W" (Button)
#define IDH_117_264	17301621	// Process parameters: "X" (Button)
#define IDH_117_265	17367157	// Process parameters: "" (Edit)
#define IDH_117_267	17498229	// Process parameters: "0" (Edit)
#define IDH_117_271	17760373	// Process parameters: "0" (Edit)
#define IDH_117_275	18022517	// Process parameters: "Advance time" (Button)
#define IDH_117_276	18088053	// Process parameters: "Do not advance time" (Button)

/*
*/

// "Program options" Dialog Box (IDD_PROGOPTS == 118)

#define IDH_118_278	18219126	// Program options: "" (Edit)
#define IDH_118_279	18284662	// Program options: "Binary job files" (Button)
#define IDH_118_280	18350198	// Program options: "Verbose (display result)" (Button)
#define IDH_118_281	18415734	// Program options: "Created jobs NOT exported" (Button)
#define IDH_118_282	18481270	// Program options: "" (Edit)

/*
*/

// "Job redirections" Dialog Box (IDD_REDIRLIST == 119)

#define IDH_119_283	18546807	// Job redirections: "" (ListBox)
#define IDH_119_284	18612343	// Job redirections: "New" (Button)
#define IDH_119_285	18677879	// Job redirections: "Edit" (Button)
#define IDH_119_286	18743415	// Job redirections: "Delete" (Button)

/*
*/

// "Job time limits" Dialog Box (IDD_TIMELIMS == 120)

#define IDH_120_346	22675576	// Job time limits: "" (Edit)
#define IDH_120_332	21758072	// Job time limits: "0" (Edit)
#define IDH_120_289	18940024	// Job time limits: "" (Edit)
#define IDH_120_337	22085752	// Job time limits: "OFF" (Button)
#define IDH_120_338	22151288	// Job time limits: "Sigterm" (Button)

/*
*/

// "Set job time" Dialog Box (IDD_TIMER == 121)

#define IDH_121_301	19726457	// Set job time: "Run and delete" (Button)
#define IDH_121_302	19791993	// Set job time: "Run and retain" (Button)
#define IDH_121_326	21364857	// Set job time: "Skip" (Button)
#define IDH_121_303	19857529	// Set job time: "Minutes" (Button)
#define IDH_121_327	21430393	// Set job time: "Delay Current" (Button)
#define IDH_121_304	19923065	// Set job time: "Hours" (Button)
#define IDH_121_328	21495929	// Set job time: "Delay all" (Button)
#define IDH_121_305	19988601	// Set job time: "Days" (Button)
#define IDH_121_329	21561465	// Set job time: "Catch up" (Button)
#define IDH_121_306	20054137	// Set job time: "Weeks" (Button)
#define IDH_121_307	20119673	// Set job time: "Months (rel begin)" (Button)
#define IDH_121_331	21692537	// Set job time: "" (Edit)
#define IDH_121_308	20185209	// Set job time: "Months (rel end)" (Button)
#define IDH_121_309	20250745	// Set job time: "Years" (Button)
#define IDH_121_287	18808953	// Set job time: "Set time for job" (Button)
#define IDH_121_311	20381817	// Set job time: "0" (Edit)
#define IDH_121_289	18940025	// Set job time: "" (Edit)
#define IDH_121_314	20578425	// Set job time: "" (Edit)
#define IDH_121_317	20775033	// Set job time: "Sun" (Button)

/*
*/

// "Title Command Int Priority Load level" Dialog Box (IDD_TITLEPRIO == 122)

#define IDH_122_351	23003258	// Title Command Int Priority Load level: "" (Edit)
#define IDH_122_352	23068794	// Title Command Int Priority Load level: "" (ComboBox)
#define IDH_122_353	23134330	// Title Command Int Priority Load level: "0" (Edit)
#define IDH_122_355	23265402	// Title Command Int Priority Load level: "0" (Edit)

/*
*/

// "User Permissions" Dialog Box (IDD_USERPERM == 123)

#define IDH_123_357	23396475	// User Permissions: "Read admin" (Button)
#define IDH_123_247	16187515	// User Permissions: "" (Edit)
#define IDH_123_248	16253051	// User Permissions: "" (Edit)
#define IDH_123_366	23986299	// User Permissions: "" (Edit)
#define IDH_123_367	24051835	// User Permissions: "" (Edit)
#define IDH_123_368	24117371	// User Permissions: "" (Edit)

/*
*/

extern	BOOL	do_contexthelp(const UINT, const DWORD *);

